# MCC: Merchant Category Codes from
# * https://github.com/greggles/mcc-codes


codes = {
    '0': {'combined description': 'none', 'USDA description': 'none', 'IRS Description': 'none', 'Reportable under 6041/6041A and Authority for Exception': 'no'},
    '742': {'combined description': 'Veterinary Services', 'USDA description': 'Veterinary Services', 'IRS Description': 'Veterinary Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '763': {'combined description': 'Agricultural Co-operatives', 'USDA description': 'Agricultural Co-operatives', 'IRS Description': 'Agricultural Cooperative', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '780': {'combined description': 'Horticultural Services, Landscaping Services', 'USDA description': 'Horticultural Services', 'IRS Description': 'Landscaping Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '1520': {'combined description': 'General Contractors-Residential and Commercial', 'USDA description': 'General Contractors-Residential and Commercial', 'IRS Description': 'General Contractors', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '1711': {'combined description': 'Air Conditioning Contractors & Sales and Installation, Heating Contractors & Sales, Service, Installation', 'USDA description': 'Air Conditioning Contractors & Sales and Installation', 'IRS Description': 'Heating, Plumbing, A/C', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '1731': {'combined description': 'Electrical Contractors', 'USDA description': 'Electrical Contractors', 'IRS Description': 'Electrical Contractors', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '1740': {'combined description': 'Insulation & Contractors, Masonry, Stonework Contractors, Plastering Contractors, Stonework and Masonry Contractors, Tile Settings Contractors', 'USDA description': 'Insulation & Contractors', 'IRS Description': 'Masonry, Stonework, and Plaster', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '1750': {'combined description': 'Carpentry Contractors', 'USDA description': 'Carpentry Contractors', 'IRS Description': 'Carpentry Contractors', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '1761': {'combined description': 'Roofing & Contractors, Sheet Metal Work & Contractors, Siding & Contractors', 'USDA description': 'Roofing - Contractors', 'IRS Description': 'Roofing/Siding, Sheet Metal', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '1771': {'combined description': 'Contractors & Concrete Work', 'USDA description': 'Contractors & Concrete Work', 'IRS Description': 'Concrete Work Contractors', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '1799': {'combined description': 'Contractors & Special Trade, Not Elsewhere Classified', 'USDA description': 'Contractors & Special Trade, Not Elsewhere Classified', 'IRS Description': 'Special Trade Contractors', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '2741': {'combined description': 'Miscellaneous Publishing and Printing', 'USDA description': 'Miscellaneous Publishing and Printing', 'IRS Description': 'Miscellaneous Publishing and Printing', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '2791': {'combined description': 'Typesetting, Plate Making, & Related Services', 'USDA description': 'Typesetting, Plate Making, & Related Services', 'IRS Description': 'Typesetting, Plate Making, and Related Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '2842': {'combined description': 'Specialty Cleaning, Polishing, and Sanitation Preparations', 'USDA description': 'Specialty Cleaning, Polishing, and Sanitation Preparations', 'IRS Description': 'Specialty Cleaning', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3000': {'combined description': 'UNITED AIRLINES', 'USDA description': 'UNITED AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3001': {'combined description': 'AMERICAN AIRLINES', 'USDA description': 'AMERICAN AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3002': {'combined description': 'PAN AMERICAN - PAN AM', 'USDA description': 'PAN AMERICAN', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3003': {'combined description': 'EURO-FLY', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3004': {'combined description': 'TRANS WORLD AIRLINES', 'USDA description': 'TRANS WORLD AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3005': {'combined description': 'BRITSH AIRWAYS - BRITISH A', 'USDA description': 'BRITISH AIRWAYS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3006': {'combined description': 'JAPAN AIR LINES', 'USDA description': 'JAPAN AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3007': {'combined description': 'AIR FRANCE', 'USDA description': 'AIR FRANCE', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3008': {'combined description': 'LUFTHANSA', 'USDA description': 'LUFTHANSA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3009': {'combined description': 'AIR CANADA - AIR CAN', 'USDA description': 'AIR CANADA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3010': {'combined description': 'KLM', 'USDA description': 'KLM (ROYAL DUTCH AIRLINES)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3011': {'combined description': 'AEROFLOT', 'USDA description': 'AEORFLOT', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3012': {'combined description': 'QANTAS AIR', 'USDA description': 'QUANTAS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3013': {'combined description': 'ALITALIA', 'USDA description': 'ALITALIA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3014': {'combined description': 'SAUDI ARABIAN AIRLINES', 'USDA description': 'SAUDIA ARABIAN AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3015': {'combined description': 'SWISS INTERNATIONAL AIR LINES-SWISS AIR', 'USDA description': 'SWISSAIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3016': {'combined description': 'SCANDINAVIAN AIRLINE SYSTEM (SAS)', 'USDA description': 'SAS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3017': {'combined description': 'SOUTH AFRICAN AIRWAYS', 'USDA description': 'SOUTH AFRICAN AIRWAYS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3018': {'combined description': 'VARIG AIR (BRAZIL)', 'USDA description': 'VARIG (BRAZIL)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3019': {'combined description': 'GERMANWINGS--GRMNWGAIR', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3020': {'combined description': 'AIR INDIA', 'USDA description': 'AIR-INDIA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3021': {'combined description': 'AIR ALGERIE', 'USDA description': 'AIR ALGERIE', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3022': {'combined description': 'PHILIPPINE AIRLINES', 'USDA description': 'PHILIPPINE AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3023': {'combined description': 'MEXICANA', 'USDA description': 'MEXICANA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3024': {'combined description': 'PAKISTAN INTERNATIONAL', 'USDA description': 'PAKISTAN INTERNATIONAL', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3025': {'combined description': 'AIR NEW ZEALAND LTD. INTERNATIONAL', 'USDA description': 'AIR NEW ZEALAND', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3026': {'combined description': 'EMIRATES AIRLINES', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3027': {'combined description': 'UNION DE TRANSPORTS AERIENS (UTA/INTERAI', 'USDA description': 'UTA/INTERAIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3028': {'combined description': 'AIR MALTA', 'USDA description': 'AIR MALTA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3029': {'combined description': 'SN BRUSSELS AIRLINES - SNBRU AIR', 'USDA description': 'SABENA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3030': {'combined description': 'AEROLINEAS ARGENTINAS', 'USDA description': 'AEROLINEAS ARGENTINAS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3031': {'combined description': 'OLYMPIC AIRWAYS', 'USDA description': 'OLYMPIC AIRWAYS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3032': {'combined description': 'EL AL', 'USDA description': 'EL AL', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3033': {'combined description': 'ANSETT AIRLINES', 'USDA description': 'ANSETT AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3034': {'combined description': 'TRANS AUSTRALIAN AIRWAYS (TAA)', 'USDA description': 'AUSTRAINLIAN AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3035': {'combined description': 'TAP AIRLINE (PORTUGAL)', 'USDA description': 'TAP (PORTUGAL)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3036': {'combined description': 'VASP AIR (BRAZIL)', 'USDA description': 'VASP (BRAZIL)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3037': {'combined description': 'EGYPTAIR', 'USDA description': 'EGYPTAIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3038': {'combined description': 'KUWAIT AIRWAYS', 'USDA description': 'KUWAIT AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3039': {'combined description': 'AVIANCA', 'USDA description': 'AVIANCA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3040': {'combined description': 'GULF AIR (BAHRAIN)', 'USDA description': 'GULF AIR (BAHRAIN)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3041': {'combined description': 'BALKAN-BULGARIAN AIRLINES', 'USDA description': 'BALKAN-BULGARIAN AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3042': {'combined description': 'FINNAIR', 'USDA description': 'FINNAIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3043': {'combined description': 'AER LINGUS', 'USDA description': 'AER LINGUS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3044': {'combined description': 'AIR LANKA', 'USDA description': 'AIR LANKA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3045': {'combined description': 'NIGERIA AIRWAYS', 'USDA description': 'NIGERIA AIRWAYS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3046': {'combined description': 'CRUZEIRO DO SUL AIR (BRAZIL)', 'USDA description': 'CRUZEIRO DO SUL (BRAZIJ)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3047': {'combined description': 'THY AIRLINE (TURKEY)', 'USDA description': 'THY (TURKEY)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3048': {'combined description': 'AIRMARO', 'USDA description': 'ROYAL AIR MAROC', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3049': {'combined description': 'TUNIS AIR', 'USDA description': 'TUNIS AIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3050': {'combined description': 'ICELANDAIR', 'USDA description': 'ICELANDAIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3051': {'combined description': 'AUSTRIAN AIRLINES', 'USDA description': 'AUSTRIAN AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3052': {'combined description': 'LAN AIRLINES-LANAIR', 'USDA description': 'LANCHILE', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3053': {'combined description': 'AVIACO AIR (SPAIN)', 'USDA description': 'AVIACO (SPAIN)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3054': {'combined description': 'LADECO AIR (CHILE)', 'USDA description': 'LADECO (CHILE)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3055': {'combined description': 'LAB AIRLINE (BOLIVIA)', 'USDA description': 'LAB (BOLIVIA)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3056': {'combined description': 'QUEBECAIRE', 'USDA description': 'QUEBECAIRE', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3057': {'combined description': 'EAST/WEST AIRLINES (AUSTRALIA)', 'USDA description': 'EASTWEST AIRLINES (AUSTRALIA)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3058': {'combined description': 'DELTA', 'USDA description': 'DELTA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3059': {'combined description': 'DBA AIRLINES - DBA AIR', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3060': {'combined description': 'NORTHWEST AIRLINES', 'USDA description': 'NORTHWEST', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3061': {'combined description': 'CONTINENTAL', 'USDA description': 'CONTINENTAL', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3062': {'combined description': 'HAPAG-LLOYD EXPRESS - HLX', 'USDA description': 'WESTERN', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3063': {'combined description': 'US AIRWAYS', 'USDA description': 'US AIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3064': {'combined description': 'ADRIA AIRWAYS', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3065': {'combined description': 'AIRINTER', 'USDA description': 'AIRINTER', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3066': {'combined description': 'SOUTHWEST AIRLINES', 'USDA description': 'SOUTHWEST', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3067': {'combined description': 'VANGUARD AIRLINES', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3068': {'combined description': 'AIR ASTANA-AIRSTANA', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3069': {'combined description': 'AIR EUROPE', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3070': {'combined description': 'PACIFIC SOUTHWEST AIRLINE', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3071': {'combined description': 'AIR BRITISH COLUMBIA', 'USDA description': 'AIR BRITISH COLUBIA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3072': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3073': {'combined description': 'AIR CAL', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3074': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3075': {'combined description': 'SINGAPORE AIRLINES', 'USDA description': 'SINGAPORE AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3076': {'combined description': 'AEROMEXICO', 'USDA description': 'AEROMEXICO', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3077': {'combined description': 'THAI AIRWAYS', 'USDA description': 'THAI AIRWAYS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3078': {'combined description': 'CHINA AIRLINES', 'USDA description': 'CHINA AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3079': {'combined description': 'JETSTAR', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3080': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3081': {'combined description': 'NORDAIR', 'USDA description': 'NORDAIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3082': {'combined description': 'KOREAN AIRLINES', 'USDA description': 'KOREAN AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3083': {'combined description': 'AIR AFRIQUE - AIR AFRIQ', 'USDA description': 'AIR AFRIGUE', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3084': {'combined description': 'EVA AIRLINES', 'USDA description': 'EVA AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3085': {'combined description': 'MIDWEST EXPRESS AIRLINES - MIDWEST', 'USDA description': 'MIDWEST EXPRESS AIRLINES, INC.', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3086': {'combined description': 'CARNIVAL AIRLINES', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3087': {'combined description': 'METRO AIRLINES', 'USDA description': 'METRO AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3088': {'combined description': 'CROATIA AIR - CROATIA', 'USDA description': 'CROATIA AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3089': {'combined description': 'TRANSAERO', 'USDA description': 'TRANSAERO', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3090': {'combined description': 'UNI AIRWAYS', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3091': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3092': {'combined description': 'MIDWAY AIRLINES', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3093': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3094': {'combined description': 'ZAMBIA AIRWAYS', 'USDA description': 'ZAMBIA AIRWAYS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3095': {'combined description': 'WARDAIR', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3096': {'combined description': 'AIR ZIMBABWE', 'USDA description': 'AIR ZIMBABWE', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3097': {'combined description': 'SPANAIR', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3098': {'combined description': 'ASIANA AIRLINES - ASIANA', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3099': {'combined description': 'CATHAY PACIFIC', 'USDA description': 'CATHAY PACIFIC', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3100': {'combined description': 'MALAYSIAN AIRLINE SYSTEM', 'USDA description': 'MALAYSIAN AIRLINE SYSTEM', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3101': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3102': {'combined description': 'IBERIA', 'USDA description': 'IBERIA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3103': {'combined description': 'GARUDA AIR (INDONESIA)', 'USDA description': 'GARUDA (INDONESIA)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3104': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3105': {'combined description': 'PIEDMONT', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3106': {'combined description': 'BRAATHENS AIR S.A.F.E. (NORWAY)', 'USDA description': 'BRAATHENS S.A.F.E. (NORWAY)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3107': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3108': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3109': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3110': {'combined description': 'WINGS AIRWAYS', 'USDA description': 'WINGS AIRWAYS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3111': {'combined description': 'BRITISH MIDLAND', 'USDA description': 'BRITISH MIDLAND', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3112': {'combined description': 'WINDWARD ISLAND', 'USDA description': 'WINDWARD ISLAND', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3113': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3114': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3115': {'combined description': 'TOWER AIR', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3116': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3117': {'combined description': 'VENEZOLANA INTERNATIONAL DE AVIACION (VI', 'USDA description': 'VIASA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3118': {'combined description': 'VALLEY AIRLINES', 'USDA description': 'VALLEY AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3119': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3120': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3121': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3122': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3123': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3124': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3125': {'combined description': 'TAN AIRLINES', 'USDA description': 'TAN', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3126': {'combined description': 'TALAIR', 'USDA description': 'TALAIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3127': {'combined description': 'TACA INTERNATIONAL', 'USDA description': 'TACA INTERNATIONAL', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3128': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3129': {'combined description': 'SURINAM AIRWAYS', 'USDA description': 'SURINAM AIRWAYS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3130': {'combined description': 'SUNWORLD INTERNATIONAL AIR', 'USDA description': 'SUN WORLD INTERNATIONAL', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3131': {'combined description': 'VLM AIRLINES', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3132': {'combined description': 'FRONTIER AIRLINES - FRONTIER', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3133': {'combined description': 'SUNBELT AIRLINES', 'USDA description': 'SUNBELT AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3134': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3135': {'combined description': 'SUDAN AIRWAYS', 'USDA description': 'SUDAN AIRWAYS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3136': {'combined description': 'QATAR AIRWAYS', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3137': {'combined description': 'SINGLETION AIR', 'USDA description': 'SINGLETON', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3138': {'combined description': 'SIMMONS AIRLINES', 'USDA description': 'SIMMONS AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3139': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3140': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3141': {'combined description': 'SEAIR ALASKA', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3142': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3143': {'combined description': 'SCENIC AIRLINES', 'USDA description': 'SCENIC AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3144': {'combined description': 'VIRGIN ATLANTIC', 'USDA description': 'VIRGIN ATLANTIC', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3145': {'combined description': 'SAN JUAN AIRLINES', 'USDA description': 'SAN JUAN AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3146': {'combined description': 'LUXAIR', 'USDA description': 'LUXAIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3147': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3148': {'combined description': 'AIR LITTORAL, S.A.', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3149': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3150': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3151': {'combined description': 'AIR ZAIRE', 'USDA description': 'AIR ZAIRE', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3152': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3153': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3154': {'combined description': 'PRINCEVILLE', 'USDA description': 'PRINCEVILLE', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3155': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3156': {'combined description': 'GO FLY, LTD.', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3157': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3158': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3159': {'combined description': 'PROVINCETOWN-BOSTON AIRWAYS (PBA) AIRLIN', 'USDA description': 'PBA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3160': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3161': {'combined description': 'ALL NIPON AIRWAYS', 'USDA description': 'ALL NIPPON AIRWAYS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3162': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3163': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3164': {'combined description': 'NORONTAIR', 'USDA description': 'NORONTAIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3165': {'combined description': 'NEW YORK HELICOPTER', 'USDA description': 'NEW YORK HELICOPTER', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3166': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3167': {'combined description': 'AERO CONTINENTE - AERO CONT', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3168': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3169': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3170': {'combined description': 'MOUNT COOK', 'USDA description': 'NOUNT COOK', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3171': {'combined description': 'CANADIAN AIRLINES INTERNATIONAL', 'USDA description': 'CANADIAN AIRLINES INTERNATIONAL', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3172': {'combined description': 'NATIONAIR', 'USDA description': 'NATIONAIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3173': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3174': {'combined description': 'JETBLUE AIRLINES', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3175': {'combined description': 'MIDDLE EAST AIR', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3176': {'combined description': 'METROFLIGHT AIRLINES', 'USDA description': 'METROFLIGHT AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3177': {'combined description': 'AIRTRAN AIRWAYS - AIRTRAN A', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3178': {'combined description': 'MESA AIR', 'USDA description': 'MESA AIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3179': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3180': {'combined description': 'WESTJETAIR', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3181': {'combined description': 'MALEV AIR', 'USDA description': 'MALEV', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3182': {'combined description': 'LOT (POLISH AIRLINES)', 'USDA description': 'LOT (POLAND)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3183': {'combined description': 'OMANAIR', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3184': {'combined description': 'LIAT', 'USDA description': 'LIAT', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3185': {'combined description': 'LINEA AEROPOSTAL VENEZOLANA (LAV)', 'USDA description': 'LAV (VENEZUELA)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3186': {'combined description': 'LINEAS AEREAS PARAGUAYAS (LAP)', 'USDA description': 'LAP (PARAGUAY)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3187': {'combined description': 'LACSA AIR (COSTA RICA)', 'USDA description': 'LACSA (COSTA RICA)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3188': {'combined description': 'VIRGINEXPAIR', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3189': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3190': {'combined description': 'JUGOSLAV AIR', 'USDA description': 'JUGOSLAV AIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3191': {'combined description': 'ISLAND AIRLINES', 'USDA description': 'ISLAND AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3192': {'combined description': 'IRAN AIR', 'USDA description': 'IRAN AIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3193': {'combined description': 'INDIAN AIRLINES', 'USDA description': 'INDIAN AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3194': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3195': {'combined description': 'HOLIDAY AIRLINES', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3196': {'combined description': 'HAWAIIAN AIR', 'USDA description': 'HAWAIIAN AIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3197': {'combined description': 'HAVASU AIRLINES', 'USDA description': 'HAVASU AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3198': {'combined description': 'HARBOR AIRLINES', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3199': {'combined description': 'SERVICIOS AEREOS MILITARES', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3200': {'combined description': 'GUYANA AIRWAYS', 'USDA description': 'FUYANA AIRWAYS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3201': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3202': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3203': {'combined description': 'GOLDEN PACIFIC AIR', 'USDA description': 'GOLDEN PACIFIC AIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3204': {'combined description': 'FREEDOM AIRLINES', 'USDA description': 'FREEDOM AIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3205': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3206': {'combined description': 'CHINA EASTERN AIRLINES - CHINAEAST', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3207': {'combined description': 'EMPRESA ECUATORIANA', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3208': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3209': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3210': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3211': {'combined description': 'NORWEGIAN AIR SHUTTLE - NORWEGIAN', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3212': {'combined description': 'DOMINICANA DE AVIACION', 'USDA description': 'DOMINICANA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3213': {'combined description': 'MALMO AVIATION', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3214': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3215': {'combined description': 'DAN AIR SERVICES', 'USDA description': 'DAN AIR SERVICES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3216': {'combined description': 'CUMBERLAND AIRLINES', 'USDA description': 'CUMBERLAND AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3217': {'combined description': 'CESKOSLOVENSKE AEROLINIE (CSA)', 'USDA description': 'CSA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3218': {'combined description': 'CROWN AIR', 'USDA description': 'CROWN AIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3219': {'combined description': 'COMPANIA PANAMENA DE AVIACION (COPA)', 'USDA description': 'COPA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3220': {'combined description': 'COMPANIA FAUCETT', 'USDA description': 'COMPANIA FAUCETT', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3221': {'combined description': 'TRANSPORTES AEROS MILITARES ECUATORIANOS', 'USDA description': 'TRANSPORTES AEROS MILITARES ECCUATORANOS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3222': {'combined description': 'COMMAND AIRWAYS', 'USDA description': 'COMMAND AIRWAYS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3223': {'combined description': 'COMAIR', 'USDA description': 'COMAIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3224': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3225': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3226': {'combined description': 'SKYWAYS AIR', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3227': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3228': {'combined description': 'CAYMAN AIRWAYS', 'USDA description': 'CAYMAN AIRWAYS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3229': {'combined description': 'SAETA (SOCIEDAD ECUATORIANOS DE TRANSPOR', 'USDA description': 'SAETA SOCIAEDAD ECUATORIANOS DE TRANSPORTES AEREOS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3230': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3231': {'combined description': 'SAHSA (SERVICIO AERO DE HONDURAS)', 'USDA description': 'SASHA SERVICIO AERO DE HONDURAS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3232': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3233': {'combined description': 'CAPITOL AIR', 'USDA description': 'CAPITOL AIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3234': {'combined description': 'CARIBBEAN AIRLINES', 'USDA description': 'BWIA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3235': {'combined description': 'BROCKWAY AIR', 'USDA description': 'BROKWAY AIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3236': {'combined description': 'AIR ARABIA', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3237': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3238': {'combined description': 'BEMIDJI AVIATION', 'USDA description': 'BEMIDJI AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3239': {'combined description': 'BAR HARBOR AIRLINES', 'USDA description': 'BAR HARBOR AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3240': {'combined description': 'BAHAMASAIR', 'USDA description': 'BAHAMASAIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3241': {'combined description': 'AVIATECA AIR (GUATEMALA)', 'USDA description': 'AVIATECA (GUATEMALA)', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3242': {'combined description': 'CARIBBEAN AIRLINES--CARIBBEAN', 'USDA description': 'AVENSA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3243': {'combined description': 'AUSTRIAN AIR SERVICE', 'USDA description': 'AUSTRIAN AIR SERVICE', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3244': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3245': {'combined description': 'EASYJET AIR', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3246': {'combined description': 'RYANAIR', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3247': {'combined description': 'GOL AIR', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3248': {'combined description': 'TAM AIR', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3249': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3250': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3251': {'combined description': 'ALOHA AIR', 'USDA description': 'ALOHA AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3252': {'combined description': 'ANTILEAN AIRLINES (ALM)', 'USDA description': 'ALM', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3253': {'combined description': 'AMERICA WEST', 'USDA description': 'AMERICA WEST', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3254': {'combined description': 'U.S. AIR SHUTTLE', 'USDA description': 'TRUMP AIRLINE', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3255': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3256': {'combined description': 'ALASKA AIRLINES INC.', 'USDA description': 'ALASKA AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3257': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3258': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3259': {'combined description': 'AMERICAN TRANS AIR', 'USDA description': 'AMERICAN TRANS AIR', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3260': {'combined description': 'SPIRIT AIRLINES', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3261': {'combined description': 'AIR CHINA', 'USDA description': 'AIR CHINA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3262': {'combined description': 'RENO AIR', 'USDA description': 'RENO AIR, INC.', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3263': {'combined description': 'AERO SERVICIO CARABOBO - ASERCA', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3264': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3265': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3266': {'combined description': 'AIR SEYCHELLES', 'USDA description': 'AIR SEYCHELLES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3267': {'combined description': 'AIR PANAMA INTERNATIONAL', 'USDA description': 'AIR PANAMA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3268': {'combined description': 'AIR PACIFIC', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3269': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3270': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3271': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3272': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3273': {'combined description': 'RICA HOTELS', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3274': {'combined description': 'INTER NOR HOTELS', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3275': {'combined description': 'AIR NEVADA', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3276': {'combined description': 'AIR MIDWEST', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3277': {'combined description': 'AIR MADAGASCAR', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3278': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3279': {'combined description': 'AIR LA', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3280': {'combined description': 'AIR JAMAICA', 'USDA description': 'AIR JAMAICA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3281': {'combined description': 'AIR DJIBOUTI', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3282': {'combined description': 'AIR DJIBOUTI', 'USDA description': 'AIR DJIBOUTI', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3283': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3284': {'combined description': 'AERO VIRGIN ISLANDS', 'USDA description': 'AERO VIRGIN ISLANDS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3285': {'combined description': 'AERO PERU', 'USDA description': 'AERO PERU', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3286': {'combined description': 'AERO NICARAGUENSIS', 'USDA description': 'AEROLINEAS NICARAGUENSIS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3287': {'combined description': 'AERO COACH AVIATION', 'USDA description': 'AERO COACH AVAIATION', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3288': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3289': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3290': {'combined description': 'airlines', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3291': {'combined description': 'ARIANA AFGHAN', 'USDA description': 'ARIANA AFGHAN', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3292': {'combined description': 'CYPRUS AIRWAYS', 'USDA description': 'CYPRUS AIRWAYS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3293': {'combined description': 'EQUATORIANA', 'USDA description': 'ECUATORIANA', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3294': {'combined description': 'ETHIOPIAN AIRLINES', 'USDA description': 'ETHIOPIAN AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3295': {'combined description': 'KENYA AIRWAYS', 'USDA description': 'KENYA AIRLINES', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3296': {'combined description': 'AIR BERLIN - AIRBERLIN', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3297': {'combined description': 'TAROM ROMANIAN AIR TRANSPORT', 'USDA description': '', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3298': {'combined description': 'AIR MAURITIUS', 'USDA description': 'AIR MAURITIUS', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3299': {'combined description': 'WIDEROE\'S FLYVESELSKAP', 'USDA description': 'WIDERO\'S FLYVESELSKAP', 'IRS Description': 'Airlines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3351': {'combined description': 'AFFILIATED AUTO RENTAL', 'USDA description': 'AFFILIATED AUTO RENTAL', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3352': {'combined description': 'AMERICAN INTL RENT-A-CAR', 'USDA description': 'AMERICAN INTL RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3353': {'combined description': 'BROOKS RENT-A-CAR', 'USDA description': 'BROOKS RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3354': {'combined description': 'ACTION AUTO RENTAL', 'USDA description': 'ACTION AUTO RENTAL', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3355': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3356': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3357': {'combined description': 'HERTZ RENT-A-CAR', 'USDA description': 'HERTZ RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3358': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3359': {'combined description': 'PAYLESS CAR RENTAL', 'USDA description': 'PAYLESS CAR RENTAL', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3360': {'combined description': 'SNAPPY CAR RENTAL', 'USDA description': 'SNAPPY CAR RENTAL', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3361': {'combined description': 'AIRWAYS RENT-A-CAR', 'USDA description': 'AIRWAYS RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3362': {'combined description': 'ALTRA AUTO RENTAL', 'USDA description': 'ALTRA AUTO RENTAL', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3363': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3364': {'combined description': 'AGENCY RENT-A-CAR', 'USDA description': 'AGENCY RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3365': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3366': {'combined description': 'BUDGET RENT-A-CAR', 'USDA description': 'BUDGET RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3367': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3368': {'combined description': 'HOLIDAY RENT-A-WRECK', 'USDA description': 'HOLIDAY RENT-A-WRECK', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3369': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3370': {'combined description': 'RENT-A-WRECK', 'USDA description': 'RENT-A-WRECK', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3371': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3372': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3373': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3374': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3375': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3376': {'combined description': 'AJAX RENT-A-CAR', 'USDA description': 'AJAX RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3377': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3378': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3379': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3380': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3381': {'combined description': 'EUROP CAR', 'USDA description': 'EUROP CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3382': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3383': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3384': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3385': {'combined description': 'TROPICAL RENT-A-CAR', 'USDA description': 'TROPICAL RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3386': {'combined description': 'SHOWCASE RENTAL CARS', 'USDA description': 'SHOWCASE RENTAL CARS', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3387': {'combined description': 'ALAMO RENT-A-CAR', 'USDA description': 'ALAMO RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3388': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3389': {'combined description': 'AVIS RENT-A-CAR', 'USDA description': 'AVIS RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3390': {'combined description': 'DOLLAR RENT-A-CAR', 'USDA description': 'DOLLAR RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3391': {'combined description': 'EUROPE BY CAR', 'USDA description': 'EUROPE BY CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3392': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3393': {'combined description': 'NATIONAL CAR RENTAL', 'USDA description': 'NATIONAL CAR RENTAL', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3394': {'combined description': 'KEMWELL GROUP RENT-A-CAR', 'USDA description': 'KEMWELL GROUP RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3395': {'combined description': 'THRIFTY RENT-A-CAR', 'USDA description': 'THRIFTY RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3396': {'combined description': 'TILDEN TENT-A-CAR', 'USDA description': 'TILDEN TENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3397': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3398': {'combined description': 'ECONO-CAR RENT-A-CAR', 'USDA description': 'ECONO-CAR RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3399': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3400': {'combined description': 'AUTO HOST COST CAR RENTALS', 'USDA description': 'AUTO HOST COST CAR RENTALS', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3401': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3402': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3403': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3404': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3405': {'combined description': 'ENTERPRISE RENT-A-CAR', 'USDA description': 'ENTERPRISE RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3406': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3407': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3408': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3409': {'combined description': 'GENERAL RENT-A-CAR', 'USDA description': 'GENERAL RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3410': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3411': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3412': {'combined description': 'A-1 RENT-A-CAR', 'USDA description': 'A-1 RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3413': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3414': {'combined description': 'GODFREY NATL RENT-A-CAR', 'USDA description': 'GODFREY NATL RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3415': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3416': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3417': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3418': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3419': {'combined description': 'ALPHA RENT-A-CAR', 'USDA description': 'ALPHA RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3420': {'combined description': 'ANSA INTL RENT-A-CAR', 'USDA description': 'ANSA INTL RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3421': {'combined description': 'ALLSTAE RENT-A-CAR', 'USDA description': 'ALLSTAE RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3422': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3423': {'combined description': 'AVCAR RENT-A-CAR', 'USDA description': 'AVCAR RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3424': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3425': {'combined description': 'AUTOMATE RENT-A-CAR', 'USDA description': 'AUTOMATE RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3426': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3427': {'combined description': 'AVON RENT-A-CAR', 'USDA description': 'AVON RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3428': {'combined description': 'CAREY RENT-A-CAR', 'USDA description': 'CAREY RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3429': {'combined description': 'INSURANCE RENT-A-CAR', 'USDA description': 'INSURANCE RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3430': {'combined description': 'MAJOR RENT-A-CAR', 'USDA description': 'MAJOR RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3431': {'combined description': 'REPLACEMENT RENT-A-CAR', 'USDA description': 'REPLACEMENT RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3432': {'combined description': 'RESERVE RENT-A-CAR', 'USDA description': 'RESERVE RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3433': {'combined description': 'UGLY DUCKLING RENT-A-CAR', 'USDA description': 'UGLY DUCKLING RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3434': {'combined description': 'USA RENT-A-CAR', 'USDA description': 'USA RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3435': {'combined description': 'VALUE RENT-A-CAR', 'USDA description': 'VALUE RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3436': {'combined description': 'AUTOHANSA RENT-A-CAR', 'USDA description': 'AUTOHANSA RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3437': {'combined description': 'CITE RENT-A-CAR', 'USDA description': 'CITE RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3438': {'combined description': 'INTERENT RENT-A-CAR', 'USDA description': 'INTERENT RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3439': {'combined description': 'MILLEVILLE RENT-A-CAR', 'USDA description': 'MILLEVILLE RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3440': {'combined description': 'VIA ROUTE RENT-A-CAR', 'USDA description': 'VIA ROUTE RENT-A-CAR', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3441': {'combined description': 'Car Rental', 'USDA description': '', 'IRS Description': 'Car Rental', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3501': {'combined description': 'HOLIDAY INNS, HOLIDAY INN EXPRESS', 'USDA description': 'HOLIDAY INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3502': {'combined description': 'BEST WESTERN HOTELS', 'USDA description': 'BEST WESTERN HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3503': {'combined description': 'SHERATON HOTELS', 'USDA description': 'SHERATON HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3504': {'combined description': 'HILTON HOTELS', 'USDA description': 'HILTON HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3505': {'combined description': 'FORTE HOTELS', 'USDA description': 'FORTE HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3506': {'combined description': 'GOLDEN TULIP HOTELS', 'USDA description': 'GOLDEN TULIP HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3507': {'combined description': 'FRIENDSHIP INNS', 'USDA description': 'FRIENDSHIP INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3508': {'combined description': 'QUALITY INNS, QUALITY SUITES', 'USDA description': 'QUALITY INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3509': {'combined description': 'MARRIOTT HOTELS', 'USDA description': 'MARRIOTT HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3510': {'combined description': 'DAYS INN, DAYSTOP', 'USDA description': 'DAYS INN', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3511': {'combined description': 'ARABELLA HOTELS', 'USDA description': 'ARABELLA HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3512': {'combined description': 'INTER-CONTINENTAL HOTELS', 'USDA description': 'INTER-CONTINENTAL HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3513': {'combined description': 'WESTIN HOTELS', 'USDA description': 'WESTIN HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3514': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3515': {'combined description': 'RODEWAY INNS', 'USDA description': 'RODEWAY INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3516': {'combined description': 'LA QUINTA MOTOR INNS', 'USDA description': 'LA QUINTA MOTOR INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3517': {'combined description': 'AMERICANA HOTELS', 'USDA description': 'AMERICANA HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3518': {'combined description': 'SOL HOTELS', 'USDA description': 'SOL HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3519': {'combined description': 'PULLMAN INTERNATIONAL HOTELS', 'USDA description': 'PULLMAN INTERNATIONAL HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3520': {'combined description': 'MERIDIEN HOTELS', 'USDA description': 'MERIDIEN HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3521': {'combined description': 'CREST HOTELS (see FORTE HOTELS)', 'USDA description': 'CREST HOTELS (see FORTE HOTELS)', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3522': {'combined description': 'TOKYO HOTEL', 'USDA description': 'TOKYO HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3523': {'combined description': 'PENNSULA HOTEL', 'USDA description': 'PENNSULA HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3524': {'combined description': 'WELCOMGROUP HOTELS', 'USDA description': 'WELCOMGROUP HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3525': {'combined description': 'DUNFEY HOTELS', 'USDA description': 'DUNFEY HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3526': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3527': {'combined description': 'DOWNTOWNER-PASSPORT HOTEL', 'USDA description': 'DOWNTOWNER-PASSPORT HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3528': {'combined description': 'RED LION HOTELS, RED LION INNS', 'USDA description': 'RED LION HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3529': {'combined description': 'CP HOTELS', 'USDA description': 'CP HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3530': {'combined description': 'RENAISSANCE HOTELS, STOUFFER HOTELS', 'USDA description': 'RENAISSANCE HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3531': {'combined description': 'ASTIR HOTELS', 'USDA description': 'ASTIR HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3532': {'combined description': 'SUN ROUTE HOTELS', 'USDA description': 'SUN ROUTE HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3533': {'combined description': 'HOTEL IBIS', 'USDA description': 'HOTEL IBIS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3534': {'combined description': 'SOUTHERN PACIFIC HOTELS', 'USDA description': 'SOUTHERN PACIFIC HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3535': {'combined description': 'HILTON INTERNATIONAL', 'USDA description': 'HILTON INTERNATIONAL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3536': {'combined description': 'AMFAC HOTELS', 'USDA description': 'AMFAC HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3537': {'combined description': 'ANA HOTEL', 'USDA description': 'ANA HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3538': {'combined description': 'CONCORDE HOTELS', 'USDA description': 'CONCORDE HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3539': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3540': {'combined description': 'IBEROTEL HOTELS', 'USDA description': 'IBEROTEL HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3541': {'combined description': 'HOTEL OKURA', 'USDA description': 'HOTEL OKURA', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3542': {'combined description': 'ROYAL HOTELS', 'USDA description': 'ROYAL HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3543': {'combined description': 'FOUR SEASONS HOTELS', 'USDA description': 'FOUR SEASONS HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3544': {'combined description': 'CIGA HOTELS', 'USDA description': 'CIGA HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3545': {'combined description': 'SHANGRI-LA INTERNATIONAL', 'USDA description': 'SHANGRI-LA INTERNATIONAL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3546': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3547': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3548': {'combined description': 'HOTELES MELIA', 'USDA description': 'HOTELES MELIA', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3549': {'combined description': 'AUBERGE DES GOVERNEURS', 'USDA description': 'AUBERGE DES GOVERNEURS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3550': {'combined description': 'REGAL 8 INNS', 'USDA description': 'REGAL 8 INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3551': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3552': {'combined description': 'COAST HOTELS', 'USDA description': 'COAST HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3553': {'combined description': 'PARK INNS INTERNATIONAL', 'USDA description': 'PARK INNS INTERNATIONAL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3554': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3555': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3556': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3557': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3558': {'combined description': 'JOLLY HOTELS', 'USDA description': 'JOLLY HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3559': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3560': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3561': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3562': {'combined description': 'COMFORT INNS', 'USDA description': 'COMFORT INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3563': {'combined description': 'JOURNEY\'S END MOTLS', 'USDA description': 'JOURNEY\'S END MOTLS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3564': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3565': {'combined description': 'RELAX INNS', 'USDA description': 'RELAX INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3566': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3567': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3568': {'combined description': 'LADBROKE HOTELS', 'USDA description': 'LADBROKE HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3569': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3570': {'combined description': 'FORUM HOTELS', 'USDA description': 'FORUM HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3571': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3572': {'combined description': 'MIYAKO HOTELS', 'USDA description': 'MIYAKO HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3573': {'combined description': 'SANDMAN HOTELS', 'USDA description': 'SANDMAN HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3574': {'combined description': 'VENTURE INNS', 'USDA description': 'VENTURE INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3575': {'combined description': 'VAGABOND HOTELS', 'USDA description': 'VAGABOND HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3576': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3577': {'combined description': 'MANDARIN ORIENTAL HOTEL', 'USDA description': 'MANDARIN ORIENTAL HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3578': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3579': {'combined description': 'HOTEL MERCURE', 'USDA description': 'HOTEL MERCURE', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3580': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3581': {'combined description': 'DELTA HOTEL', 'USDA description': 'DELTA HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3582': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3583': {'combined description': 'SAS HOTELS', 'USDA description': 'SAS HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3584': {'combined description': 'PRINCESS HOTELS INTERNATIONAL', 'USDA description': 'PRINCESS HOTELS INTERNATIONAL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3585': {'combined description': 'HUNGAR HOTELS', 'USDA description': 'HUNGAR HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3586': {'combined description': 'SOKOS HOTELS', 'USDA description': 'SOKOS HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3587': {'combined description': 'DORAL HOTELS', 'USDA description': 'DORAL HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3588': {'combined description': 'HELMSLEY HOTELS', 'USDA description': 'HELMSLEY HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3589': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3590': {'combined description': 'FAIRMONT HOTELS', 'USDA description': 'FAIRMONT HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3591': {'combined description': 'SONESTA HOTELS', 'USDA description': 'SONESTA HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3592': {'combined description': 'OMNI HOTELS', 'USDA description': 'OMNI HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3593': {'combined description': 'CUNARD HOTELS', 'USDA description': 'CUNARD HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3594': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3595': {'combined description': 'HOSPITALITY INTERNATIONAL', 'USDA description': 'HOSPITALITY INTERNATIONAL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3596': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3597': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3598': {'combined description': 'REGENT INTERNATIONAL HOTELS', 'USDA description': 'REGENT INTERNATIONAL HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3599': {'combined description': 'PANNONIA HOTELS', 'USDA description': 'PANNONIA HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3600': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3601': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3602': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3603': {'combined description': 'NOAH\'S HOTELS', 'USDA description': 'NOAH\'S HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3604': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3605': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3606': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3607': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3608': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3609': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3610': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3611': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3612': {'combined description': 'MOVENPICK HOTELS', 'USDA description': 'MOVENPICK HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3613': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3614': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3615': {'combined description': 'TRAVELODGE', 'USDA description': 'TRAVELODGE', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3616': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3617': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3618': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3619': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3620': {'combined description': 'TELFORD INTERNATIONAL', 'USDA description': 'TELFORD INTERNATIONAL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3621': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3622': {'combined description': 'MERLIN HOTELS', 'USDA description': 'MERLIN HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3623': {'combined description': 'DORINT HOTELS', 'USDA description': 'DORINT HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3624': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3625': {'combined description': 'HOTLE UNIVERSALE', 'USDA description': 'HOTLE UNIVERSALE', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3626': {'combined description': 'PRINCE HOTELS', 'USDA description': 'PRINCE HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3627': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3628': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3629': {'combined description': 'DAN HOTELS', 'USDA description': 'DAN HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3630': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3631': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3632': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3633': {'combined description': 'RANK HOTELS', 'USDA description': 'RANK HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3634': {'combined description': 'SWISSOTEL', 'USDA description': 'SWISSOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3635': {'combined description': 'RESO HOTELS', 'USDA description': 'RESO HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3636': {'combined description': 'SAROVA HOTELS', 'USDA description': 'SAROVA HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3637': {'combined description': 'RAMADA INNS, RAMADA LIMITED', 'USDA description': 'RAMADA INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3638': {'combined description': 'HO JO INN, HOWARD JOHNSON', 'USDA description': 'HO JO INN', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3639': {'combined description': 'MOUNT CHARLOTTE THISTLE', 'USDA description': 'MOUNT CHARLOTTE THISTLE', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3640': {'combined description': 'HYATT HOTEL', 'USDA description': 'HYATT HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3641': {'combined description': 'SOFITEL HOTELS', 'USDA description': 'SOFITEL HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3642': {'combined description': 'NOVOTEL HOTELS', 'USDA description': 'NOVOTEL HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3643': {'combined description': 'STEIGENBERGER HOTELS', 'USDA description': 'STEIGENBERGER HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3644': {'combined description': 'ECONO LODGES', 'USDA description': 'ECONO LODGES', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3645': {'combined description': 'QUEENS MOAT HOUSES', 'USDA description': 'QUEENS MOAT HOUSES', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3646': {'combined description': 'SWALLOW HOTELS', 'USDA description': 'SWALLOW HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3647': {'combined description': 'HUSA HOTELS', 'USDA description': 'HUSA HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3648': {'combined description': 'DE VERE HOTELS', 'USDA description': 'DE VERE HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3649': {'combined description': 'RADISSON HOTELS', 'USDA description': 'RADISSON HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3650': {'combined description': 'RED ROOK INNS', 'USDA description': 'RED ROOK INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3651': {'combined description': 'IMPERIAL LONDON HOTEL', 'USDA description': 'IMPERIAL LONDON HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3652': {'combined description': 'EMBASSY HOTELS', 'USDA description': 'EMBASSY HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3653': {'combined description': 'PENTA HOTELS', 'USDA description': 'PENTA HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3654': {'combined description': 'LOEWS HOTELS', 'USDA description': 'LOEWS HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3655': {'combined description': 'SCANDIC HOTELS', 'USDA description': 'SCANDIC HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3656': {'combined description': 'SARA HOTELS', 'USDA description': 'SARA HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3657': {'combined description': 'OBEROI HOTELS', 'USDA description': 'OBEROI HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3658': {'combined description': 'OTANI HOTELS', 'USDA description': 'OTANI HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3659': {'combined description': 'TAJ HOTELS INTERNATIONAL', 'USDA description': 'TAJ HOTELS INTERNATIONAL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3660': {'combined description': 'KNIGHTS INNS', 'USDA description': 'KNIGHTS INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3661': {'combined description': 'METROPOLE HOTELS', 'USDA description': 'METROPOLE HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3662': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3663': {'combined description': 'HOTELES EL PRESIDENTS', 'USDA description': 'HOTELES EL PRESIDENTS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3664': {'combined description': 'FLAG INN', 'USDA description': 'FLAG INN', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3665': {'combined description': 'HAMPTON INNS', 'USDA description': 'HAMPTON INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3666': {'combined description': 'STAKIS HOTELS', 'USDA description': 'STAKIS HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3667': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3668': {'combined description': 'MARITIM HOTELS', 'USDA description': 'MARITIM HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3669': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3670': {'combined description': 'ARCARD HOTELS', 'USDA description': 'ARCARD HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3671': {'combined description': 'ARCTIA HOTELS', 'USDA description': 'ARCTIA HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3672': {'combined description': 'CAMPANIEL HOTELS', 'USDA description': 'CAMPANIEL HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3673': {'combined description': 'IBUSZ HOTELS', 'USDA description': 'IBUSZ HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3674': {'combined description': 'RANTASIPI HOTELS', 'USDA description': 'RANTASIPI HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3675': {'combined description': 'INTERHOTEL CEDOK', 'USDA description': 'INTERHOTEL CEDOK', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3676': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3677': {'combined description': 'CLIMAT DE FRANCE HOTELS', 'USDA description': 'CLIMAT DE FRANCE HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3678': {'combined description': 'CUMULUS HOTELS', 'USDA description': 'CUMULUS HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3679': {'combined description': 'DANUBIUS HOTEL', 'USDA description': 'DANUBIUS HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3680': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3681': {'combined description': 'ADAMS MARK HOTELS', 'USDA description': 'ADAMS MARK HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3682': {'combined description': 'ALLSTAR INNS', 'USDA description': 'ALLSTAR INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3683': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3684': {'combined description': 'BUDGET HOST INNS', 'USDA description': 'BUDGET HOST INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3685': {'combined description': 'BUDGETEL HOTELS', 'USDA description': 'BUDGETEL HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3686': {'combined description': 'SUISSE CHALETS', 'USDA description': 'SUISSE CHALETS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3687': {'combined description': 'CLARION HOTELS', 'USDA description': 'CLARION HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3688': {'combined description': 'COMPRI HOTELS', 'USDA description': 'COMPRI HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3689': {'combined description': 'CONSORT HOTELS', 'USDA description': 'CONSORT HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3690': {'combined description': 'COURTYARD BY MARRIOTT', 'USDA description': 'COURTYARD BY MARRIOTT', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3691': {'combined description': 'DILLION INNS', 'USDA description': 'DILLION INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3692': {'combined description': 'DOUBLETREE HOTELS', 'USDA description': 'DOUBLETREE HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3693': {'combined description': 'DRURY INNS', 'USDA description': 'DRURY INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3694': {'combined description': 'ECONOMY INNS OF AMERICA', 'USDA description': 'ECONOMY INNS OF AMERICA', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3695': {'combined description': 'EMBASSY SUITES', 'USDA description': 'EMBASSY SUITES', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3696': {'combined description': 'EXEL INNS', 'USDA description': 'EXEL INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3697': {'combined description': 'FARFIELD HOTELS', 'USDA description': 'FARFIELD HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3698': {'combined description': 'HARLEY HOTELS', 'USDA description': 'HARLEY HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3699': {'combined description': 'MIDWAY MOTOR LODGE', 'USDA description': 'MIDWAY MOTOR LODGE', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3700': {'combined description': 'MOTEL 6', 'USDA description': 'MOTEL 6', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3701': {'combined description': 'GUEST QUARTERS (Formally PICKETT SUITE HOTELS)', 'USDA description': 'GUEST QUARTERS (Formally PICKETT SUITE HOTELS)', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3702': {'combined description': 'THE REGISTRY HOTELS', 'USDA description': 'THE REGISTRY HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3703': {'combined description': 'RESIDENCE INNS', 'USDA description': 'RESIDENCE INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3704': {'combined description': 'ROYCE HOTELS', 'USDA description': 'ROYCE HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3705': {'combined description': 'SANDMAN INNS', 'USDA description': 'SANDMAN INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3706': {'combined description': 'SHILO INNS', 'USDA description': 'SHILO INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3707': {'combined description': 'SHONEY\'S INNS', 'USDA description': 'SHONEY\'S INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3708': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3709': {'combined description': 'SUPER8 MOTELS', 'USDA description': 'SUPER8 MOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3710': {'combined description': 'THE RITZ CARLTON HOTELS', 'USDA description': 'THE RITZ CARLTON HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3711': {'combined description': 'FLAG INNS (AUSRALIA)', 'USDA description': 'FLAG INNS (AUSRALIA)', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3712': {'combined description': 'GOLDEN CHAIN HOTEL', 'USDA description': 'GOLDEN CHAIN HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3713': {'combined description': 'QUALITY PACIFIC HOTEL', 'USDA description': 'QUALITY PACIFIC HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3714': {'combined description': 'FOUR SEASONS HOTEL (AUSTRALIA)', 'USDA description': 'FOUR SEASONS HOTEL (AUSTRALIA)', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3715': {'combined description': 'FARIFIELD INN', 'USDA description': 'FARIFIELD INN', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3716': {'combined description': 'CARLTON HOTELS', 'USDA description': 'CARLTON HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3717': {'combined description': 'CITY LODGE HOTELS', 'USDA description': 'CITY LODGE HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3718': {'combined description': 'KAROS HOTELS', 'USDA description': 'KAROS HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3719': {'combined description': 'PROTEA HOTELS', 'USDA description': 'PROTEA HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3720': {'combined description': 'SOUTHERN SUN HOTELS', 'USDA description': 'SOUTHERN SUN HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3721': {'combined description': 'HILTON CONRAD', 'USDA description': 'HILTON CONRAD', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3722': {'combined description': 'WYNDHAM HOTEL AND RESORTS', 'USDA description': 'WYNDHAM HOTEL AND RESORTS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3723': {'combined description': 'RICA HOTELS', 'USDA description': 'RICA HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3724': {'combined description': 'INER NOR HOTELS', 'USDA description': 'INER NOR HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3725': {'combined description': 'SEAINES PLANATION', 'USDA description': 'SEAINES PLANATION', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3726': {'combined description': 'RIO SUITES', 'USDA description': 'RIO SUITES', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3727': {'combined description': 'BROADMOOR HOTEL', 'USDA description': 'BROADMOOR HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3728': {'combined description': 'BALLY\'S HOTEL AND CASINO', 'USDA description': 'BALLY\'S HOTEL AND CASINO', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3729': {'combined description': 'JOHN ASCUAGA\'S NUGGET', 'USDA description': 'JOHN ASCUAGA\'S NUGGET', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3730': {'combined description': 'MGM GRAND HOTEL', 'USDA description': 'MGM GRAND HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3731': {'combined description': 'HARRAH\'S HOTELS AND CASINOS', 'USDA description': 'HARRAH\'S HOTELS AND CASINOS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3732': {'combined description': 'OPRYLAND HOTEL', 'USDA description': 'OPRYLAND HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3733': {'combined description': 'BOCA RATON RESORT', 'USDA description': 'BOCA RATON RESORT', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3734': {'combined description': 'HARVEY/BRISTOL HOTELS', 'USDA description': 'HARVEY/BRISTOL HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3735': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3736': {'combined description': 'COLORADO BELLE/EDGEWATER RESORT', 'USDA description': 'COLORADO BELLE/EDGEWATER RESORT', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3737': {'combined description': 'RIVIERA HOTEL AND CASINO', 'USDA description': 'RIVIERA HOTEL AND CASINO', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3738': {'combined description': 'TROPICANA RESORT AND CASINO', 'USDA description': 'TROPICANA RESORT AND CASINO', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3739': {'combined description': 'WOODSIDE HOTELS AND RESORTS', 'USDA description': 'WOODSIDE HOTELS AND RESORTS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3740': {'combined description': 'TOWNPLACE SUITES', 'USDA description': 'TOWNPLACE SUITES', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3741': {'combined description': 'MILLENIUM BROADWAY HOTEL', 'USDA description': 'MILLENIUM BROADWAY HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3742': {'combined description': 'CLUB MED', 'USDA description': 'CLUB MED', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3743': {'combined description': 'BILTMORE HOTEL AND SUITES', 'USDA description': 'BILTMORE HOTEL AND SUITES', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3744': {'combined description': 'CAREFREE RESORTS', 'USDA description': 'CAREFREE RESORTS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3745': {'combined description': 'ST. REGIS HOTEL', 'USDA description': 'ST. REGIS HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3746': {'combined description': 'THE ELIOT HOTEL', 'USDA description': 'THE ELIOT HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3747': {'combined description': 'CLUBCORP/CLUB RESORTS', 'USDA description': 'CLUBCORP/CLUB RESORTS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3748': {'combined description': 'WELESLEY INNS', 'USDA description': 'WELESLEY INNS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3749': {'combined description': 'THE BEVERLY HILLS HOTEL', 'USDA description': 'THE BEVERLY HILLS HOTEL', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3750': {'combined description': 'CROWNE PLAZA HOTELS', 'USDA description': 'CROWNE PLAZA HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3751': {'combined description': 'HOMEWOOD SUITES', 'USDA description': 'HOMEWOOD SUITES', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3752': {'combined description': 'PEABODY HOTELS', 'USDA description': 'PEABODY HOTELS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3753': {'combined description': 'GREENBRIAH RESORTS', 'USDA description': 'GREENBRIAH RESORTS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3754': {'combined description': 'AMELIA ISLAND PLANATION', 'USDA description': 'AMELIA ISLAND PLANATION', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3755': {'combined description': 'THE HOMESTEAD', 'USDA description': 'THE HOMESTEAD', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3756': {'combined description': 'SOUTH SEAS RESORTS', 'USDA description': 'SOUTH SEAS RESORTS', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3757': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3758': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3759': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3760': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3761': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3762': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3763': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3764': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3765': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3766': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3767': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3768': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3769': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3770': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3771': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3772': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3773': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3774': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3775': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3776': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3777': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3778': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3779': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3780': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3781': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3782': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3783': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3784': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3785': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3786': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3787': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3788': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3789': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3790': {'combined description': 'Hotels/Motels/Inns/Resorts', 'USDA description': '', 'IRS Description': 'Hotels/Motels/Inns/Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '3835': {'combined description': '* MASTERS ECONOMY INNS', 'USDA description': '* MASTERS ECONOMY INNS', 'IRS Description': '', 'Reportable under 6041/6041A and Authority for Exception': ''},
    '4011': {'combined description': 'Railroads', 'USDA description': '', 'IRS Description': 'Railroads', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '4111': {'combined description': 'Local/Suburban Commuter Passenger Transportation & Railroads, Feries, Local Water Transportation.', 'USDA description': 'Local/Suburban Commuter Passenger Transportation & Railroads, Feries, Local Water Transportation.', 'IRS Description': 'Commuter Transport, Ferries', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '4112': {'combined description': 'Passenger Railways', 'USDA description': 'Passenger Railways', 'IRS Description': 'Passenger Railways', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '4119': {'combined description': 'Ambulance Services', 'USDA description': 'Ambulance Services', 'IRS Description': 'Ambulance Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '4121': {'combined description': 'Taxicabs and Limousines', 'USDA description': 'Taxicabs and Limousines', 'IRS Description': 'Taxicabs/Limousines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '4131': {'combined description': 'Bus Lines, Including Charters, Tour Buses', 'USDA description': 'Bus Lines, Including Charters, Tour Buses', 'IRS Description': 'Bus Lines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '4214': {'combined description': 'Motor Freight Carriers, Moving and Storage Companies, Trucking & Local/Long Distance, Delivery Services & Local', 'USDA description': 'Motor Freight Carriers', 'IRS Description': 'Motor Freight Carriers and Trucking - Local and Long Distance, Moving and Storage Companies, and Local Delivery Services ', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '4215': {'combined description': 'Courier Services & Air or Ground, Freight forwarders', 'USDA description': 'Courier Services & Air or Ground', 'IRS Description': 'Courier Services ', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '4225': {'combined description': 'Public warehousing, Storage', 'USDA description': 'Warehousing, Public', 'IRS Description': 'Public Warehousing and Storage - Farm Products, Refrigerated Goods, Household Goods, and Storage ', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '4411': {'combined description': 'Cruise and Steamship Lines', 'USDA description': 'Cruise Lines', 'IRS Description': 'Cruise Lines', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '4457': {'combined description': 'Boat Rentals and Leases', 'USDA description': 'Boat Rentals and Leases', 'IRS Description': 'Boat Rentals and Leases', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '4468': {'combined description': 'Marinas, Marine Service, and Supplies', 'USDA description': 'Marinas, Marine Service, and Supplies', 'IRS Description': 'Marinas, Service and Supplies', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '4511': {'combined description': 'Airlines, Air Carriers ( not listed elsewhere)', 'USDA description': 'Airlines, Air Carriers ( not listed elsewhere)', 'IRS Description': 'Airlines, Air Carriers', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '4582': {'combined description': 'Airports, Airport Terminals, Flying Fields', 'USDA description': 'Airports, Airport Terminals', 'IRS Description': 'Airports, Flying Fields', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '4722': {'combined description': 'Travel Agencies and Tour Operations', 'USDA description': 'Travel Agencies and Tour Operations', 'IRS Description': 'Travel Agencies, Tour Operators', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '4723': {'combined description': 'Package Tour Operators (For use in Germany only)', 'USDA description': 'Package Tour Operators (For use in Germany only)', 'IRS Description': 'TUI Travel - Germany', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '4784': {'combined description': 'Toll and Bridge Fees', 'USDA description': 'Toll and Bridge Fees', 'IRS Description': 'Tolls/Bridge Fees', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '4789': {'combined description': 'Transportation Services, Not elsewhere classified)', 'USDA description': 'Transportation Services, Not elsewhere classified)', 'IRS Description': 'Transportation Services (Not Elsewhere Classified)', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '4812': {'combined description': 'Telecommunications Equipment including telephone sales', 'USDA description': 'Telecommunications Equipment including telephone sales', 'IRS Description': 'Telecommunication Equipment and Telephone Sales', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '4814': {'combined description': 'Fax services, Telecommunication Services', 'USDA description': 'Fax services', 'IRS Description': 'Telecommunication Services', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '4815': {'combined description': 'VisaPhone', 'USDA description': 'VisaPhone', 'IRS Description': '', 'Reportable under 6041/6041A and Authority for Exception': ''},
    '4816': {'combined description': 'Computer Network Services', 'USDA description': '', 'IRS Description': 'Computer Network Services', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '4821': {'combined description': 'Telegraph services', 'USDA description': 'Telegraph services', 'IRS Description': 'Telegraph Services', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '4829': {'combined description': 'Money Orders & Wire Transfer', 'USDA description': 'Money Orders & Wire Transfer', 'IRS Description': 'Wires, Money Orders', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '4899': {'combined description': 'Cable and other pay television (previously Cable Services)', 'USDA description': 'Cable and other pay television (previously Cable Services)', 'IRS Description': 'Cable, Satellite, and Other Pay Television and Radio', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '4900': {'combined description': 'Electric, Gas, Sanitary and Water Utilities', 'USDA description': 'Electric, Gas, Sanitary and Water Utilities', 'IRS Description': 'Utilities ', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5013': {'combined description': 'Motor vehicle supplies and new parts', 'USDA description': 'Motor vehicle supplies and new parts', 'IRS Description': 'Motor Vehicle Supplies and New Parts', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5021': {'combined description': 'Office and Commercial Furniture', 'USDA description': 'Office and Commercial Furniture', 'IRS Description': 'Office and Commercial Furniture', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5039': {'combined description': 'Construction Materials, Not Elsewhere Classified', 'USDA description': 'Construction Materials, Not Elsewhere Classified', 'IRS Description': 'Construction Materials (Not Elsewhere Classified)', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5044': {'combined description': 'Office, Photographic, Photocopy, and Microfilm Equipment', 'USDA description': 'Office, Photographic, Photocopy, and Microfilm Equipment', 'IRS Description': 'Photographic, Photocopy, Microfilm Equipment, and Supplies', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5045': {'combined description': 'Computers, Computer Peripheral Equipment, Software', 'USDA description': 'Computers, Computer Peripheral Equipment, Software', 'IRS Description': 'Computers, Peripherals, and Software', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5046': {'combined description': 'Commercial Equipment, Not Elsewhere Classified', 'USDA description': 'Commercial Equipment, Not Elsewhere Classified', 'IRS Description': 'Commercial Equipment (Not Elsewhere Classified)', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5047': {'combined description': 'Medical, Dental Ophthalmic, Hospital Equipment and Supplies', 'USDA description': 'Medical, Dental Ophthalmic, Hospital Equipment and Supplies', 'IRS Description': 'Medical, Dental, Ophthalmic, and Hospital Equipment and Supplies', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5051': {'combined description': 'Metal Service Centers and Offices', 'USDA description': 'Metal Service Centers and Offices', 'IRS Description': 'Metal Service Centers', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5065': {'combined description': 'Electrical Parts and Equipment', 'USDA description': 'Electrical Parts and Equipment', 'IRS Description': 'Electrical Parts and Equipment', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5072': {'combined description': 'Hardware Equipment and Supplies', 'USDA description': 'Hardware Equipment and Supplies', 'IRS Description': 'Hardware, Equipment, and Supplies', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5074': {'combined description': 'Plumbing and Heating Equipment and Supplies', 'USDA description': 'Plumbing and Heating Equipment and Supplies', 'IRS Description': 'Plumbing, Heating Equipment, and Supplies', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5085': {'combined description': 'Industrial Supplies, Not Elsewhere Classified', 'USDA description': 'Industrial Supplies, Not Elsewhere Classified', 'IRS Description': 'Industrial Supplies (Not Elsewhere Classified)', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5094': {'combined description': 'Precious Stones and Metals, Watches and Jewelry', 'USDA description': 'Precious Stones and Metals, Watches and Jewelry', 'IRS Description': 'Precious Stones and Metals, Watches and Jewelry', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5099': {'combined description': 'Durable Goods, Not Elsewhere Classified', 'USDA description': 'Durable Goods, Not Elsewhere Classified', 'IRS Description': 'Durable Goods (Not Elsewhere Classified)', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5111': {'combined description': 'Stationery, Office Supplies, Printing, and Writing Paper', 'USDA description': 'Stationery, Office Supplies, Printing, and Writing Paper', 'IRS Description': 'Stationary, Office Supplies, Printing and Writing Paper', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5122': {'combined description': 'Drugs, Drug Proprietors, and Druggist\'s Sundries', 'USDA description': 'Drugs, Drug Proprietors, and Druggist\'s Sundries', 'IRS Description': 'Drugs, Drug Proprietaries, and Druggist Sundries', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5131': {'combined description': 'Piece Goods, Notions, and Other Dry Goods', 'USDA description': 'Piece Goods, Notions, and Other Dry Goods', 'IRS Description': 'Piece Goods, Notions, and Other Dry Goods', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5137': {'combined description': 'Men\'s Women\'s and Children\'s Uniforms and Commercial Clothing', 'USDA description': 'Men\'s Women\'s and Children\'s Uniforms and Commercial Clothing', 'IRS Description': 'Uniforms, Commercial Clothing', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5139': {'combined description': 'Commercial Footwear', 'USDA description': 'Commercial Footwear', 'IRS Description': 'Commercial Footwear', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5169': {'combined description': 'Chemicals and Allied Products, Not Elsewhere Classified', 'USDA description': 'Chemicals and Allied Products, Not Elsewhere Classified', 'IRS Description': 'Chemicals and Allied Products (Not Elsewhere Classified)', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5172': {'combined description': 'Petroleum and Petroleum Products', 'USDA description': 'Petroleum and Petroleum Products', 'IRS Description': 'Petroleum and Petroleum Products', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5192': {'combined description': 'Books, Periodicals, and Newspapers', 'USDA description': 'Books, Periodicals, and Newspapers', 'IRS Description': 'Books, Periodicals, and Newspapers', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5193': {'combined description': 'Florists\' Supplies, Nursery Stock and Flowers', 'USDA description': 'Florists\' Supplies, Nursery Stock and Flowers', 'IRS Description': 'Florists Supplies, Nursery Stock, and Flowers', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5198': {'combined description': 'Paints, Varnishes, and Supplies', 'USDA description': 'Paints, Varnishes, and Supplies', 'IRS Description': 'Paints, Varnishes, and Supplies', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5199': {'combined description': 'Non-durable Goods, Not Elsewhere Classified', 'USDA description': 'Non-durable Goods, Not Elsewhere Classified', 'IRS Description': 'Nondurable Goods (Not Elsewhere Classified)', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5200': {'combined description': 'Home Supply Warehouse Stores', 'USDA description': 'Home Supply Warehouse Stores', 'IRS Description': 'Home Supply Warehouse Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5211': {'combined description': 'Lumber and Building Materials Stores', 'USDA description': 'Lumber and Building Materials Stores', 'IRS Description': 'Lumber, Building Materials Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5231': {'combined description': 'Glass, Paint, and Wallpaper Stores', 'USDA description': 'Wallpaper Stores', 'IRS Description': 'Glass, Paint, and Wallpaper Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5251': {'combined description': 'Hardware Stores', 'USDA description': 'Hardware Stores', 'IRS Description': 'Hardware Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5261': {'combined description': 'Nurseries & Lawn and Garden Supply Store', 'USDA description': 'Nurseries & Lawn and Garden Supply Store', 'IRS Description': 'Nurseries, Lawn and Garden Supply Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5271': {'combined description': 'Mobile Home Dealers', 'USDA description': 'Mobile Home Dealers', 'IRS Description': 'Mobile Home Dealers', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5300': {'combined description': 'Wholesale Clubs', 'USDA description': 'Wholesale Clubs', 'IRS Description': 'Wholesale Clubs', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5309': {'combined description': 'Duty Free Store', 'USDA description': 'Duty Free Store', 'IRS Description': 'Duty Free Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5310': {'combined description': 'Discount Stores', 'USDA description': 'Discount Stores', 'IRS Description': 'Discount Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5311': {'combined description': 'Department Stores', 'USDA description': 'Department Stores', 'IRS Description': 'Department Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5331': {'combined description': 'Variety Stores', 'USDA description': 'Variety Stores', 'IRS Description': 'Variety Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5399': {'combined description': 'Misc. General Merchandise', 'USDA description': 'Misc. General Merchandise', 'IRS Description': 'Miscellaneous General Merchandise', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5411': {'combined description': 'Grocery Stores, Supermarkets', 'USDA description': 'Grocery Stores', 'IRS Description': 'Grocery Stores, Supermarkets', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5422': {'combined description': 'Meat Provisioners & Freezer and Locker', 'USDA description': 'Meat Provisioners & Freezer and Locker', 'IRS Description': 'Freezer and Locker Meat Provisioners', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5441': {'combined description': 'Candy, Nut, and Confectionery Stores', 'USDA description': 'Candy Stores', 'IRS Description': 'Candy, Nut, and Confectionery Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5451': {'combined description': 'Dairy Products Stores', 'USDA description': 'Dairy Products Stores', 'IRS Description': 'Dairy Products Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5462': {'combined description': 'Bakeries', 'USDA description': 'Bakeries', 'IRS Description': 'Bakeries', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5499': {'combined description': 'Misc. Food Stores & Convenience Stores and Specialty Markets', 'USDA description': 'Misc. Food Stores & Convenience Stores and Specialty Markets', 'IRS Description': 'Miscellaneous Food Stores - Convenience Stores and Specialty Markets', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5511': {'combined description': 'Car and Truck Dealers (New and Used) Sales, Service, Repairs, Parts, and Leasing', 'USDA description': 'Car and Truck Dealers (New and Used) Sales, Service, Repairs, Parts, and Leasing', 'IRS Description': 'Car and Truck Dealers (New & Used) Sales, Service, Repairs Parts and Leasing ', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5521': {'combined description': 'Automobile and Truck Dealers (Used Only)', 'USDA description': 'Automobile and Truck Dealers (Used Only)', 'IRS Description': 'Car and Truck Dealers (Used Only) Sales, Service, Repairs Parts and Leasing ', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5531': {'combined description': 'Automobile Supply Stores', 'USDA description': 'Automobile Supply Stores', 'IRS Description': 'Auto and Home Supply Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5532': {'combined description': 'Automotive Tire Stores', 'USDA description': 'Automotive Tire Stores', 'IRS Description': 'Automotive Tire Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5533': {'combined description': 'Automotive Parts, Accessories Stores', 'USDA description': 'Automotive Parts, Accessories Stores', 'IRS Description': 'Automotive Parts and Accessories Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5541': {'combined description': 'Service Stations ( with or without ancillary services)', 'USDA description': 'Service Stations ( with or without ancillary services)', 'IRS Description': 'Service Stations ', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5542': {'combined description': 'Automated Fuel Dispensers', 'USDA description': 'Automated Fuel Dispensers', 'IRS Description': 'Automated Fuel Dispensers', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5551': {'combined description': 'Boat Dealers', 'USDA description': 'Boat Dealers', 'IRS Description': 'Boat Dealers', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5561': {'combined description': 'Recreational and Utility Trailers, Camp Dealers', 'USDA description': 'Recreational and Utility Trailers, Camp Dealers', 'IRS Description': 'Motorcycle Shops, Dealers', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5571': {'combined description': 'Motorcycle Dealers', 'USDA description': 'Motorcycle Dealers', 'IRS Description': 'Motorcycle Shops and Dealers', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5592': {'combined description': 'Motor Home Dealers', 'USDA description': 'Motor Home Dealers', 'IRS Description': 'Motor Homes Dealers', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5598': {'combined description': 'Snowmobile Dealers', 'USDA description': 'Snowmobile Dealers', 'IRS Description': 'Snowmobile Dealers', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5599': {'combined description': 'Miscellaneous Auto Dealers ', 'USDA description': '', 'IRS Description': 'Miscellaneous Auto Dealers ', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5611': {'combined description': 'Men\'s and Boy\'s Clothing and Accessories Stores', 'USDA description': 'Men\'s and Boy\'s Clothing and Accessories Stores', 'IRS Description': 'Men\'s and Boy\'s Clothing and Accessories Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5621': {'combined description': 'Women\'s Ready-to-Wear Stores', 'USDA description': 'Women\'s Ready-to-Wear Stores', 'IRS Description': 'Women\'s Ready-To-Wear Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5631': {'combined description': 'Women\'s Accessory and Specialty Shops', 'USDA description': 'Women\'s Accessory and Specialty Shops', 'IRS Description': 'Women\'s Accessory and Specialty Shops', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5641': {'combined description': 'Children\'s and Infant\'s Wear Stores', 'USDA description': 'Children\'s and Infant\'s Wear Stores', 'IRS Description': 'Children\'s and Infant\'s Wear Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5651': {'combined description': 'Family Clothing Stores', 'USDA description': 'Family Clothing Stores', 'IRS Description': 'Family Clothing Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5655': {'combined description': 'Sports Apparel, Riding Apparel Stores', 'USDA description': 'Sports Apparel, Riding Apparel Stores', 'IRS Description': 'Sports and Riding Apparel Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5661': {'combined description': 'Shoe Stores', 'USDA description': 'Shoe Stores', 'IRS Description': 'Shoe Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5681': {'combined description': 'Furriers and Fur Shops', 'USDA description': 'Furriers and Fur Shops', 'IRS Description': 'Furriers and Fur Shops', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5691': {'combined description': 'Men\'s and Women\'s Clothing Stores', 'USDA description': 'Men\'s and Women\'s Clothing Stores', 'IRS Description': 'Men\'s, Women\'s Clothing Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5697': {'combined description': 'Tailors, Seamstress, Mending, and Alterations', 'USDA description': 'Tailors, Seamstress, Mending, and Alterations', 'IRS Description': 'Tailors, Alterations', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '5698': {'combined description': 'Wig and Toupee Stores', 'USDA description': 'Wig and Toupee Stores', 'IRS Description': 'Wig and Toupee Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5699': {'combined description': 'Miscellaneous Apparel and Accessory Shops', 'USDA description': 'Miscellaneous Apparel and Accessory Shops', 'IRS Description': 'Miscellaneous Apparel and Accessory Shops', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5712': {'combined description': 'Furniture, Home Furnishings, and Equipment Stores, ExceptAppliances', 'USDA description': 'Furniture, Home Furnishings, and Equipment Stores, ExceptAppliances', 'IRS Description': 'Furniture, Home Furnishings, and Equipment Stores, Except Appliances', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5713': {'combined description': 'Floor Covering Stores', 'USDA description': 'Floor Covering Stores', 'IRS Description': 'Floor Covering Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5714': {'combined description': 'Drapery, Window Covering and Upholstery Stores', 'USDA description': 'Drapery, Window Covering and Upholstery Stores', 'IRS Description': 'Drapery, Window Covering, and Upholstery Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5718': {'combined description': 'Fireplace, Fireplace Screens, and Accessories Stores', 'USDA description': 'Fireplace, Fireplace Screens, and Accessories Stores', 'IRS Description': 'Fireplace, Fireplace Screens, and Accessories Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5719': {'combined description': 'Miscellaneous Home Furnishing Specialty Stores', 'USDA description': 'Miscellaneous Home Furnishing Specialty Stores', 'IRS Description': 'Miscellaneous Home Furnishing Specialty Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5722': {'combined description': 'Household Appliance Stores', 'USDA description': 'Household Appliance Stores', 'IRS Description': 'Household Appliance Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5732': {'combined description': 'Electronic Sales', 'USDA description': 'Electronic Sales', 'IRS Description': 'Electronics Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5733': {'combined description': 'Music Stores, Musical Instruments, Piano Sheet Music', 'USDA description': 'Music Stores, Musical Instruments, Piano Sheet Music', 'IRS Description': 'Music Stores-Musical Instruments, Pianos, and Sheet Music', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5734': {'combined description': 'Computer Software Stores', 'USDA description': 'Computer Software Stores', 'IRS Description': 'Computer Software Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5735': {'combined description': 'Record Shops', 'USDA description': 'Record Shops', 'IRS Description': 'Record Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5811': {'combined description': 'Caterers', 'USDA description': 'Caterers', 'IRS Description': 'Caterers', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '5812': {'combined description': 'Eating places and Restaurants', 'USDA description': 'Eating places and Restaurants', 'IRS Description': 'Eating Places, Restaurants', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5813': {'combined description': 'Drinking Places (Alcoholic Beverages), Bars, Taverns, Cocktail lounges, Nightclubs and Discotheques', 'USDA description': 'Drinking Places (Alcoholic Beverages), Bars, Taverns, Cocktail lounges, Nightclubs and Discotheques', 'IRS Description': 'Drinking Places', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5814': {'combined description': 'Fast Food Restaurants', 'USDA description': 'Fast Food Restaurants', 'IRS Description': 'Fast Food Restaurants', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5832': {'combined description': 'Antique Shops & Sales, Repairs, and Restoration Services', 'USDA description': 'Antique Shops & Sales, Repairs, and Restoration Services', 'IRS Description': '', 'Reportable under 6041/6041A and Authority for Exception': ''},
    '5912': {'combined description': 'Drug Stores and Pharmacies', 'USDA description': 'Drug Stores and Pharmacies', 'IRS Description': 'Drug Stores and Pharmacies', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5921': {'combined description': 'Package Stores & Beer, Wine, and Liquor', 'USDA description': 'Package Stores & Beer, Wine, and Liquor', 'IRS Description': 'Package Stores-Beer, Wine, and Liquor', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5931': {'combined description': 'Used Merchandise and Secondhand Stores', 'USDA description': 'Used Merchandise and Secondhand Stores', 'IRS Description': 'Used Merchandise and Secondhand Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5932': {'combined description': 'Antique Shops', 'USDA description': '', 'IRS Description': 'Antique Shops', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5933': {'combined description': 'Pawn Shops and Salvage Yards', 'USDA description': 'Pawn Shops and Salvage Yards', 'IRS Description': 'Pawn Shops', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5935': {'combined description': 'Wrecking and Salvage Yards', 'USDA description': 'Wrecking and Salvage Yards', 'IRS Description': 'Wrecking and Salvage Yards', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '5937': {'combined description': 'Antique Reproductions', 'USDA description': 'Antique Reproductions', 'IRS Description': 'Antique Reproductions', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5940': {'combined description': 'Bicycle Shops & Sales and Service', 'USDA description': 'Bicycle Shops & Sales and Service', 'IRS Description': 'Bicycle Shops', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5941': {'combined description': 'Sporting Goods Stores', 'USDA description': 'Sporting Goods Stores', 'IRS Description': 'Sporting Goods Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5942': {'combined description': 'Book Stores', 'USDA description': 'Book Stores', 'IRS Description': 'Book Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5943': {'combined description': 'Stationery Stores, Office and School Supply Stores', 'USDA description': 'Stationery Stores, Office and School Supply Stores', 'IRS Description': 'Stationery Stores, Office, and School Supply Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5944': {'combined description': 'Watch, Clock, Jewelry, and Silverware Stores', 'USDA description': 'Watch, Clock, Jewelry, and Silverware Stores', 'IRS Description': 'Jewelry Stores, Watches, Clocks, and Silverware Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5945': {'combined description': 'Hobby, Toy, and Game Shops', 'USDA description': 'Hobby, Toy, and Game Shops', 'IRS Description': 'Hobby, Toy, and Game Shops', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5946': {'combined description': 'Camera and Photographic Supply Stores', 'USDA description': 'Camera and Photographic Supply Stores', 'IRS Description': 'Camera and Photographic Supply Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5947': {'combined description': 'Card Shops, Gift, Novelty, and Souvenir Shops', 'USDA description': 'Card Shops, Gift, Novelty, and Souvenir Shops', 'IRS Description': 'Gift, Card, Novelty, and Souvenir Shops', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5948': {'combined description': 'Leather Foods Stores', 'USDA description': 'Leather Foods Stores', 'IRS Description': 'Luggage and Leather Goods Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5949': {'combined description': 'Sewing, Needle, Fabric, and Price Goods Stores', 'USDA description': 'Sewing, Needle, Fabric, and Price Goods Stores', 'IRS Description': 'Sewing, Needlework, Fabric, and Piece Goods Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5950': {'combined description': 'Glassware/Crystal Stores', 'USDA description': 'Glassware/Crystal Stores', 'IRS Description': 'Glassware, Crystal Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5960': {'combined description': 'Direct Marketing- Insurance Service', 'USDA description': 'Direct Marketing- Insurance Service', 'IRS Description': 'Direct Marketing - Insurance Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '5961': {'combined description': 'Mail Order Houses Including Catalog Order Stores, Book/Record Clubs (No longer permitted for U.S. original presentments)', 'USDA description': 'Mail Order Houses Including Catalog Order Stores, Book/Record Clubs (No longer permitted for U.S. original presentments)', 'IRS Description': '', 'Reportable under 6041/6041A and Authority for Exception': ''},
    '5962': {'combined description': 'Direct Marketing & Travel Related Arrangements Services', 'USDA description': 'Direct Marketing & Travel Related Arrangements Services', 'IRS Description': 'Direct Marketing - Travel', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '5963': {'combined description': 'Door-to-Door Sales', 'USDA description': 'Door-to-Door Sales', 'IRS Description': 'Door-To-Door Sales', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5964': {'combined description': 'Direct Marketing & Catalog Merchant', 'USDA description': 'Direct Marketing & Catalog Merchant', 'IRS Description': 'Direct Marketing - Catalog Merchant', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5965': {'combined description': 'Direct Marketing & Catalog and Catalog and Retail Merchant', 'USDA description': 'Direct Marketing & Catalog and Catalog and Retail Merchant', 'IRS Description': 'Direct Marketing - Combination Catalog and Retail Merchant', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5966': {'combined description': 'Direct Marketing- Outbound Telemarketing Merchant', 'USDA description': 'Direct Marketing- Outbound Telemarketing Merchant', 'IRS Description': 'Direct Marketing - Outbound Tele', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5967': {'combined description': 'Direct Marketing & Inbound Teleservices Merchant', 'USDA description': 'Direct Marketing & Inbound Teleservices Merchant', 'IRS Description': 'Direct Marketing - Inbound Tele', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5968': {'combined description': 'Direct Marketing & Continuity/Subscription Merchant', 'USDA description': 'Direct Marketing & Continuity/Subscription Merchant', 'IRS Description': 'Direct Marketing - Subscription', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5969': {'combined description': 'Direct Marketing & Not Elsewhere Classified', 'USDA description': 'Direct Marketing & Not Elsewhere Classified', 'IRS Description': 'Direct Marketing - Other ', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5970': {'combined description': 'Artist\'s Supply and Craft Shops', 'USDA description': 'Artist\'s Supply and Craft Shops', 'IRS Description': 'Artist\'s Supply and Craft Shops', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5971': {'combined description': 'Art Dealers and Galleries', 'USDA description': 'Art Dealers and Galleries', 'IRS Description': 'Art Dealers and Galleries', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5972': {'combined description': 'Stamp and Coin Stores & Philatelic and Numismatic Supplies', 'USDA description': 'Stamp and Coin Stores & Philatelic and Numismatic Supplies', 'IRS Description': 'Stamp and Coin Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5973': {'combined description': 'Religious Goods Stores', 'USDA description': 'Religious Goods Stores', 'IRS Description': 'Religious Goods Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5975': {'combined description': 'Hearing Aids & Sales, Service, and Supply Stores', 'USDA description': 'Hearing Aids & Sales, Service, and Supply Stores', 'IRS Description': 'Hearing Aids Sales and Supplies', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5976': {'combined description': 'Orthopedic Goods Prosthetic Devices', 'USDA description': 'Orthopedic Goods Prosthetic Devices', 'IRS Description': 'Orthopedic Goods - Prosthetic Devices', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5977': {'combined description': 'Cosmetic Stores', 'USDA description': 'Cosmetic Stores', 'IRS Description': 'Cosmetic Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5978': {'combined description': 'Typewriter Stores & Sales, Rental, Service', 'USDA description': 'Typewriter Stores & Sales, Rental, Service', 'IRS Description': 'Typewriter Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5983': {'combined description': 'Fuel & Fuel Oil, Wood, Coal, Liquefied Petroleum', 'USDA description': 'Fuel & Fuel Oil, Wood, Coal, Liquefied Petroleum', 'IRS Description': 'Fuel Dealers (Non Automotive)', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5992': {'combined description': 'Florists', 'USDA description': 'Florists', 'IRS Description': 'Florists', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5993': {'combined description': 'Cigar Stores and Stands', 'USDA description': 'Cigar Stores and Stands', 'IRS Description': 'Cigar Stores and Stands', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5994': {'combined description': 'News Dealers and Newsstands', 'USDA description': 'News Dealers and Newsstands', 'IRS Description': 'News Dealers and Newsstands', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5995': {'combined description': 'Pet Shops, Pet Foods, and Supplies Stores', 'USDA description': 'Pet Shops, Pet Foods, and Supplies Stores', 'IRS Description': 'Pet Shops, Pet Food, and Supplies', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5996': {'combined description': 'Swimming Pools & Sales, Service, and Supplies', 'USDA description': 'Swimming Pools & Sales, Service, and Supplies', 'IRS Description': 'Swimming Pools Sales', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5997': {'combined description': 'Electric Razor Stores & Sales and Service', 'USDA description': 'Electric Razor Stores & Sales and Service', 'IRS Description': 'Electric Razor Stores', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5998': {'combined description': 'Tent and Awning Shops', 'USDA description': 'Tent and Awning Shops', 'IRS Description': 'Tent and Awning Shops', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '5999': {'combined description': 'Miscellaneous and Specialty Retail Stores', 'USDA description': 'Miscellaneous and Specialty Retail Stores', 'IRS Description': 'Miscellaneous Specialty Retail', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '6010': {'combined description': 'Financial Institutions & Manual Cash Disbursements', 'USDA description': 'Financial Institutions & Manual Cash Disbursements', 'IRS Description': 'Manual Cash Disburse', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '6011': {'combined description': 'Financial Institutions & Manual Cash Disbursements', 'USDA description': 'Financial Institutions & Manual Cash Disbursements', 'IRS Description': 'Automated Cash Disburse', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '6012': {'combined description': 'Financial Institutions & Merchandise and Services', 'USDA description': 'Financial Institutions & Merchandise and Services', 'IRS Description': 'Financial Institutions', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '6051': {'combined description': 'Non-Financial Institutions & Foreign Currency, Money Orders (not wire transfer) and Travelers Cheques', 'USDA description': 'Non-Financial Institutions & Foreign Currency, Money Orders (not wire transfer) and Travelers Cheques', 'IRS Description': 'Non-FI, Money Orders', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '6211': {'combined description': 'Security Brokers/Dealers', 'USDA description': 'Security Brokers/Dealers', 'IRS Description': 'Security Brokers/Dealers', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '6300': {'combined description': 'Insurance Sales, Underwriting, and Premiums', 'USDA description': 'Insurance Sales, Underwriting, and Premiums', 'IRS Description': 'Insurance Underwriting, Premiums', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '6381': {'combined description': 'Insurance Premiums, (no longer valid for first presentment work)', 'USDA description': 'Insurance Premiums, (no longer valid for first presentment work)', 'IRS Description': '', 'Reportable under 6041/6041A and Authority for Exception': ''},
    '6399': {'combined description': 'Insurance, Not Elsewhere Classified ( no longer valid forfirst presentment work)', 'USDA description': 'Insurance, Not Elsewhere Classified ( no longer valid forfirst presentment work)', 'IRS Description': 'Insurance - Default', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '6513': {'combined description': 'Real Estate Agents and Managers - Rentals', 'USDA description': '', 'IRS Description': 'Real Estate Agents and Managers - Rentals', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7011': {'combined description': 'Lodging & Hotels, Motels, Resorts, Central Reservation Services (not elsewhere classified)', 'USDA description': 'Lodging & Hotels, Motels, Resorts, Central Reservation Services (not elsewhere classified)', 'IRS Description': 'Hotels, Motels, and Resorts', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7012': {'combined description': 'Timeshares', 'USDA description': 'Timeshares', 'IRS Description': 'Timeshares', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7032': {'combined description': 'Sporting and Recreational Camps', 'USDA description': 'Sporting and Recreational Camps', 'IRS Description': 'Sporting/Recreation Camps', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7033': {'combined description': 'Trailer Parks and Camp Grounds', 'USDA description': 'Trailer Parks and Camp Grounds', 'IRS Description': 'Trailer Parks, Campgrounds', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7210': {'combined description': 'Laundry, Cleaning, and Garment Services', 'USDA description': 'Laundry, Cleaning, and Garment Services', 'IRS Description': 'Laundry, Cleaning Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7211': {'combined description': 'Laundry & Family and Commercial', 'USDA description': 'Laundry & Family and Commercial', 'IRS Description': 'Laundries ', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7216': {'combined description': 'Dry Cleaners', 'USDA description': 'Dry Cleaners', 'IRS Description': 'Dry Cleaners', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7217': {'combined description': 'Carpet and Upholstery Cleaning', 'USDA description': 'Carpet and Upholstery Cleaning', 'IRS Description': 'Carpet/Upholstery Cleaning', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7221': {'combined description': 'Photographic Studios', 'USDA description': 'Photographic Studios', 'IRS Description': 'Photographic Studios', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7230': {'combined description': 'Barber and Beauty Shops', 'USDA description': 'Barber and Beauty Shops', 'IRS Description': 'Barber and Beauty Shops', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7251': {'combined description': 'Shop Repair Shops and Shoe Shine Parlors, and Hat Cleaning Shops', 'USDA description': 'Shop Repair Shops and Shoe Shine Parlors, and Hat Cleaning Shops', 'IRS Description': 'Shoe Repair/Hat Cleaning', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7261': {'combined description': 'Funeral Service and Crematories', 'USDA description': 'Funeral Service and Crematories', 'IRS Description': 'Funeral Services, Crematories', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7273': {'combined description': 'Dating and Escort Services', 'USDA description': 'Dating and Escort Services', 'IRS Description': 'Dating/Escort Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7276': {'combined description': 'Tax Preparation Service', 'USDA description': 'Tax Preparation Service', 'IRS Description': 'Tax Preparation Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7277': {'combined description': 'Counseling Service & Debt, Marriage, Personal', 'USDA description': 'Counseling Service & Debt, Marriage, Personal', 'IRS Description': 'Counseling Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7278': {'combined description': 'Buying/Shopping Services, Clubs', 'USDA description': 'Buying/Shopping Services, Clubs', 'IRS Description': 'Buying/Shopping Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7296': {'combined description': 'Clothing Rental & Costumes, Formal Wear, Uniforms', 'USDA description': 'Clothing Rental & Costumes, Formal Wear, Uniforms', 'IRS Description': 'Clothing Rental ', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7297': {'combined description': 'Massage Parlors', 'USDA description': 'Massage Parlors', 'IRS Description': 'Massage Parlors', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7298': {'combined description': 'Health and Beauty Shops', 'USDA description': 'Health and Beauty Shops', 'IRS Description': 'Health and Beauty Spas', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7299': {'combined description': 'Miscellaneous Personal Services ( not elsewhere classifies)', 'USDA description': 'Miscellaneous Personal Services ( not elsewhere classifies)', 'IRS Description': 'Miscellaneous General Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7311': {'combined description': 'Advertising Services', 'USDA description': 'Advertising Services', 'IRS Description': 'Advertising Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7321': {'combined description': 'Consumer Credit Reporting Agencies', 'USDA description': 'Consumer Credit Reporting Agencies', 'IRS Description': 'Credit Reporting Agencies', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7332': {'combined description': 'Blueprinting and Photocopying Services', 'USDA description': 'Blueprinting and Photocopying Services', 'IRS Description': '', 'Reportable under 6041/6041A and Authority for Exception': ''},
    '7333': {'combined description': 'Commercial Photography, Art and Graphics', 'USDA description': 'Commercial Photography, Art and Graphics', 'IRS Description': 'Commercial Photography, Art and Graphics', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7338': {'combined description': 'Quick Copy, Reproduction and Blueprinting Services', 'USDA description': 'Quick Copy, Reproduction and Blueprinting Services', 'IRS Description': 'Quick Copy, Repro, and Blueprint', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7339': {'combined description': 'Stenographic and Secretarial Support Services', 'USDA description': 'Stenographic and Secretarial Support Services', 'IRS Description': 'Secretarial Support Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7342': {'combined description': 'Exterminating and Disinfecting Services', 'USDA description': 'Exterminating and Disinfecting Services', 'IRS Description': 'Exterminating Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7349': {'combined description': 'Cleaning and Maintenance, Janitorial Services', 'USDA description': 'Cleaning and Maintenance, Janitorial Services', 'IRS Description': 'Cleaning and Maintenance', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7361': {'combined description': 'Employment Agencies, Temporary Help Services', 'USDA description': 'Employment Agencies, Temporary Help Services', 'IRS Description': 'Employment/Temp Agencies', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7372': {'combined description': 'Computer Programming, Integrated Systems Design and Data Processing Services', 'USDA description': 'Computer Programming, Integrated Systems Design and Data Processing Services', 'IRS Description': 'Computer Programming', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7375': {'combined description': 'Information Retrieval Services', 'USDA description': 'Information Retrieval Services', 'IRS Description': 'Information Retrieval Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7379': {'combined description': 'Computer Maintenance and Repair Services, Not Elsewhere Classified', 'USDA description': 'Computer Maintenance and Repair Services, Not Elsewhere Classified', 'IRS Description': 'Computer Repair', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7392': {'combined description': 'Management, Consulting, and Public Relations Services', 'USDA description': 'Management, Consulting, and Public Relations Services', 'IRS Description': 'Consulting, Public Relations', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7393': {'combined description': 'Protective and Security Services & Including Armored Carsand Guard Dogs', 'USDA description': 'Protective and Security Services & Including Armored Carsand Guard Dogs', 'IRS Description': 'Detective Agencies', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7394': {'combined description': 'Equipment Rental and Leasing Services, Tool Rental, Furniture Rental, and Appliance Rental', 'USDA description': 'Equipment Rental and Leasing Services, Tool Rental, Furniture Rental, and Appliance Rental', 'IRS Description': 'Equipment Rental ', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7395': {'combined description': 'Photofinishing Laboratories, Photo Developing', 'USDA description': 'Photofinishing Laboratories, Photo Developing', 'IRS Description': 'Photo Developing', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7399': {'combined description': 'Business Services, Not Elsewhere Classified', 'USDA description': 'Business Services, Not Elsewhere Classified', 'IRS Description': 'Miscellaneous Business Services ', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7511': {'combined description': 'Truck Stop', 'USDA description': '', 'IRS Description': 'Truck Stop', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7512': {'combined description': 'Car Rental Companies ( Not Listed Below)', 'USDA description': 'Car Rental Companies ( Not Listed Below)', 'IRS Description': 'Car Rental Agencies', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7513': {'combined description': 'Truck and Utility Trailer Rentals', 'USDA description': 'Truck and Utility Trailer Rentals', 'IRS Description': 'Truck/Utility Trailer Rentals', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7519': {'combined description': 'Motor Home and Recreational Vehicle Rentals', 'USDA description': 'Motor Home and Recreational Vehicle Rentals', 'IRS Description': 'Recreational Vehicle Rentals', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7523': {'combined description': 'Automobile Parking Lots and Garages', 'USDA description': 'Automobile Parking Lots and Garages', 'IRS Description': 'Parking Lots, Garages', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7531': {'combined description': 'Automotive Body Repair Shops', 'USDA description': 'Automotive Body Repair Shops', 'IRS Description': 'Auto Body Repair Shops', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7534': {'combined description': 'Tire Re-treading and Repair Shops', 'USDA description': 'Tire Re-treading and Repair Shops', 'IRS Description': 'Tire Retreading and Repair', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7535': {'combined description': 'Paint Shops & Automotive', 'USDA description': 'Paint Shops & Automotive', 'IRS Description': 'Auto Paint Shops', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7538': {'combined description': 'Automotive Service Shops', 'USDA description': 'Automotive Service Shops', 'IRS Description': 'Auto Service Shops', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7542': {'combined description': 'Car Washes', 'USDA description': 'Car Washes', 'IRS Description': 'Car Washes', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7549': {'combined description': 'Towing Services', 'USDA description': 'Towing Services', 'IRS Description': 'Towing Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7622': {'combined description': 'Radio Repair Shops', 'USDA description': 'Radio Repair Shops', 'IRS Description': 'Electronics Repair Shops', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7623': {'combined description': 'Air Conditioning and Refrigeration Repair Shops', 'USDA description': 'Air Conditioning and Refrigeration Repair Shops', 'IRS Description': 'A/C, Refrigeration Repair', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7629': {'combined description': 'Electrical And Small Appliance Repair Shops', 'USDA description': 'Electrical And Small Appliance Repair Shops', 'IRS Description': 'Small Appliance Repair', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7631': {'combined description': 'Watch, Clock, and Jewelry Repair', 'USDA description': 'Watch, Clock, and Jewelry Repair', 'IRS Description': 'Watch/Jewelry Repair', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7641': {'combined description': 'Furniture, Furniture Repair, and Furniture Refinishing', 'USDA description': 'Furniture, Furniture Repair, and Furniture Refinishing', 'IRS Description': 'Furniture Repair, Refinishing', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7692': {'combined description': 'Welding Repair', 'USDA description': 'Welding Repair', 'IRS Description': 'Welding Repair', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7699': {'combined description': 'Repair Shops and Related Services &Miscellaneous', 'USDA description': 'Repair Shops and Related Services &Miscellaneous', 'IRS Description': 'Miscellaneous Repair Shops', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7829': {'combined description': 'Motion Pictures and Video Tape Production and Distribution', 'USDA description': 'Motion Pictures and Video Tape Production and Distribution', 'IRS Description': 'Picture/Video Production', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7832': {'combined description': 'Motion Picture Theaters', 'USDA description': 'Motion Picture Theaters', 'IRS Description': 'Motion Picture Theaters', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7841': {'combined description': 'Video Tape Rental Stores', 'USDA description': 'Video Tape Rental Stores', 'IRS Description': 'Video Tape Rental Stores', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7911': {'combined description': 'Dance Halls, Studios and Schools', 'USDA description': 'Dance Halls, Studios and Schools', 'IRS Description': 'Dance Hall, Studios, Schools', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7922': {'combined description': 'Theatrical Producers (Except Motion Pictures), Ticket Agencies', 'USDA description': 'Theatrical Producers (Except Motion Pictures), Ticket Agencies', 'IRS Description': 'Theatrical Ticket Agencies', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7929': {'combined description': 'Bands, Orchestras, and Miscellaneous Entertainers (Not Elsewhere Classified)', 'USDA description': 'Bands, Orchestras, and Miscellaneous Entertainers (Not Elsewhere Classified)', 'IRS Description': 'Bands, Orchestras', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7932': {'combined description': 'Billiard and Pool Establishments', 'USDA description': 'Billiard and Pool Establishments', 'IRS Description': 'Billiard/Pool Establishments', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7933': {'combined description': 'Bowling Alleys', 'USDA description': 'Bowling Alleys', 'IRS Description': 'Bowling Alleys', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7941': {'combined description': 'Commercial Sports, Athletic Fields, Professional Sport Clubs, and Sport Promoters', 'USDA description': 'Commercial Sports, Athletic Fields, Professional Sport Clubs, and Sport Promoters', 'IRS Description': 'Sports Clubs/Fields', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7991': {'combined description': 'Tourist Attractions and Exhibits', 'USDA description': 'Tourist Attractions and Exhibits', 'IRS Description': 'Tourist Attractions and Exhibits', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7992': {'combined description': 'Golf Courses & Public', 'USDA description': 'Golf Courses & Public', 'IRS Description': 'Golf Courses - Public', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7993': {'combined description': 'Video Amusement Game Supplies', 'USDA description': 'Video Amusement Game Supplies', 'IRS Description': 'Video Amusement Game Supplies', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '7994': {'combined description': 'Video Game Arcades/Establishments', 'USDA description': 'Video Game Arcades/Establishments', 'IRS Description': 'Video Game Arcades', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7995': {'combined description': 'Betting (including Lottery Tickets, Casino Gaming Chips, Off-track Betting and Wagers)', 'USDA description': 'Betting (including Lottery Tickets, Casino Gaming Chips, Off-track Betting and Wagers)', 'IRS Description': 'Betting/Casino Gambling', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7996': {'combined description': 'Amusement Parks, Carnivals, Circuses, Fortune Tellers', 'USDA description': 'Amusement Parks, Carnivals, Circuses, Fortune Tellers', 'IRS Description': 'Amusement Parks/Carnivals', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7997': {'combined description': 'Membership Clubs (Sports, Recreation, Athletic), Country Clubs, and Private Golf Courses', 'USDA description': 'Membership Clubs (Sports, Recreation, Athletic), Country Clubs, and Private Golf Courses', 'IRS Description': 'Country Clubs', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7998': {'combined description': 'Aquariums, Sea-aquariums, Dolphinariums', 'USDA description': 'Aquariums, Sea-aquariums, Dolphinariums', 'IRS Description': 'Aquariums', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '7999': {'combined description': 'Recreation Services (Not Elsewhere Classified)', 'USDA description': 'Recreation Services (Not Elsewhere Classified)', 'IRS Description': 'Miscellaneous Recreation Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8011': {'combined description': 'Doctors and Physicians (Not Elsewhere Classified)', 'USDA description': 'Doctors and Physicians (Not Elsewhere Classified)', 'IRS Description': 'Doctors', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8021': {'combined description': 'Dentists and Orthodontists', 'USDA description': 'Dentists and Orthodontists', 'IRS Description': 'Dentists, Orthodontists', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8031': {'combined description': 'Osteopaths', 'USDA description': 'Osteopaths', 'IRS Description': 'Osteopaths', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8041': {'combined description': 'Chiropractors', 'USDA description': 'Chiropractors', 'IRS Description': 'Chiropractors', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8042': {'combined description': 'Optometrists and Ophthalmologists', 'USDA description': 'Optometrists and Ophthalmologists', 'IRS Description': 'Optometrists, Ophthalmologist', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8043': {'combined description': 'Opticians, Opticians Goods and Eyeglasses', 'USDA description': 'Opticians, Opticians Goods and Eyeglasses', 'IRS Description': 'Opticians, Eyeglasses', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8044': {'combined description': 'Opticians, Optical Goods, and Eyeglasses (no longer validfor first presentments)', 'USDA description': 'Opticians, Optical Goods, and Eyeglasses (no longer validfor first presentments)', 'IRS Description': '', 'Reportable under 6041/6041A and Authority for Exception': ''},
    '8049': {'combined description': 'Podiatrists and Chiropodists', 'USDA description': 'Podiatrists and Chiropodists', 'IRS Description': 'Chiropodists, Podiatrists', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8050': {'combined description': 'Nursing and Personal Care Facilities', 'USDA description': 'Nursing and Personal Care Facilities', 'IRS Description': 'Nursing/Personal Care ', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8062': {'combined description': 'Hospitals', 'USDA description': 'Hospitals', 'IRS Description': 'Hospitals', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8071': {'combined description': 'Medical and Dental Laboratories', 'USDA description': 'Medical and Dental Laboratories', 'IRS Description': 'Medical and Dental Labs', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8099': {'combined description': 'Medical Services and Health Practitioners (Not Elsewhere Classified)', 'USDA description': 'Medical Services and Health Practitioners (Not Elsewhere Classified)', 'IRS Description': 'Medical Services ', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8111': {'combined description': 'Legal Services and Attorneys', 'USDA description': 'Legal Services and Attorneys', 'IRS Description': 'Legal Services, Attorneys', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8211': {'combined description': 'Elementary and Secondary Schools', 'USDA description': 'Elementary and Secondary Schools', 'IRS Description': 'Elementary, Secondary Schools', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(p)(2)'},
    '8220': {'combined description': 'Colleges, Junior Colleges, Universities, and ProfessionalSchools', 'USDA description': 'Colleges, Junior Colleges, Universities, and ProfessionalSchools', 'IRS Description': 'Colleges, Universities', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(p)(2)'},
    '8241': {'combined description': 'Correspondence Schools', 'USDA description': 'Correspondence Schools', 'IRS Description': 'Correspondence Schools', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(p)(2)'},
    '8244': {'combined description': 'Business and Secretarial Schools', 'USDA description': 'Business and Secretarial Schools', 'IRS Description': 'Business/Secretarial Schools', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(p)(2)'},
    '8249': {'combined description': 'Vocational Schools and Trade Schools', 'USDA description': 'Vocational Schools and Trade Schools', 'IRS Description': 'Vocational/Trade Schools', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(p)(2)'},
    '8299': {'combined description': 'Schools and Educational Services ( Not Elsewhere Classified)', 'USDA description': 'Schools and Educational Services ( Not Elsewhere Classified)', 'IRS Description': 'Educational Services ', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8351': {'combined description': 'Child Care Services', 'USDA description': 'Child Care Services', 'IRS Description': 'Child Care Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8398': {'combined description': 'Charitable and Social Service Organizations', 'USDA description': 'Charitable and Social Service Organizations', 'IRS Description': 'Charitable and Social Service Organizations - Fundraising', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(p)(2)'},
    '8641': {'combined description': 'Civic, Fraternal, and Social Associations', 'USDA description': 'Civic, Fraternal, and Social Associations', 'IRS Description': 'Civic, Social, Fraternal Associations', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(p)(2)'},
    '8651': {'combined description': 'Political Organizations', 'USDA description': 'Political Organizations', 'IRS Description': 'Political Organizations', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8661': {'combined description': 'Religious Organizations', 'USDA description': 'Religious Organizations', 'IRS Description': 'Religious Organizations', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(p)(2)'},
    '8675': {'combined description': 'Automobile Associations', 'USDA description': 'Automobile Associations', 'IRS Description': 'Automobile Associations', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8699': {'combined description': 'Membership Organizations ( Not Elsewhere Classified)', 'USDA description': 'Membership Organizations ( Not Elsewhere Classified)', 'IRS Description': 'Membership Organizations', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8734': {'combined description': 'Testing Laboratories ( non-medical)', 'USDA description': 'Testing Laboratories ( non-medical)', 'IRS Description': 'Testing Laboratories', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8911': {'combined description': 'Architectural & Engineering and Surveying Services', 'USDA description': 'Architectural & Engineering and Surveying Services', 'IRS Description': 'Architectural/Surveying Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8931': {'combined description': 'Accounting, Auditing, and Bookkeeping Services', 'USDA description': 'Accounting, Auditing, and Bookkeeping Services', 'IRS Description': 'Accounting/Bookkeeping Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '8999': {'combined description': 'Professional Services ( Not Elsewhere Defined)', 'USDA description': 'Professional Services ( Not Elsewhere Defined)', 'IRS Description': 'Professional Services', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '9211': {'combined description': 'Court Costs, including Alimony and Child Support', 'USDA description': 'Court Costs, including Alimony and Child Support', 'IRS Description': 'Court Costs, Including Alimony and Child Support - Courts of Law', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(p)(4)'},
    '9222': {'combined description': 'Fines', 'USDA description': 'Fines', 'IRS Description': 'Fines - Government Administrative Entities', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(p)(4)'},
    '9223': {'combined description': 'Bail and Bond Payments', 'USDA description': 'Bail and Bond Payments', 'IRS Description': 'Bail and Bond Payments (payment to the surety for the bond, not the actual bond paid to the government agency) ', 'Reportable under 6041/6041A and Authority for Exception': 'Yes'},
    '9311': {'combined description': 'Tax Payments', 'USDA description': 'Tax Payments', 'IRS Description': 'Tax Payments - Government Agencies', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(p)(4)'},
    '9399': {'combined description': 'Government Services ( Not Elsewhere Classified)', 'USDA description': 'Government Services ( Not Elsewhere Classified)', 'IRS Description': 'Government Services (Not Elsewhere Classified)', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(p)(4)'},
    '9402': {'combined description': 'Postal Services & Government Only', 'USDA description': 'Postal Services & Government Only', 'IRS Description': 'Postal Services - Government Only', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(p)(3)'},
    '9405': {'combined description': 'Intra & Government Transactions', 'USDA description': 'Intra & Government Transactions', 'IRS Description': 'U.S. Federal Government Agencies or Departments', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(p)(3)'},
    '9700': {'combined description': 'Automated Referral Service ( For Visa Only)', 'USDA description': 'Automated Referral Service ( For Visa Only)', 'IRS Description': '', 'Reportable under 6041/6041A and Authority for Exception under 6041/6041A and Authority for Exception': ''},
    '9701': {'combined description': 'Visa Credential Service ( For Visa Only)', 'USDA description': 'Visa Credential Service ( For Visa Only)', 'IRS Description': '', 'Reportable under 6041/6041A and Authority for Exception': ''},
    '9702': {'combined description': 'GCAS Emergency Services ( For Visa Only)', 'USDA description': 'GCAS Emergency Services ( For Visa Only)', 'IRS Description': '', 'Reportable under 6041/6041A and Authority for Exception': ''},
    '9950': {'combined description': 'Intra & Company Purchases ( For Visa Only)', 'USDA description': 'Intra & Company Purchases ( For Visa Only)', 'IRS Description': 'Intra-Company Purchases', 'Reportable under 6041/6041A and Authority for Exception': 'No1.6041-3(c)'},
    '9999': {'combined description': 'MCC Invalid', 'USDA description': 'MCC Invalid', 'IRS Description': 'MCC Invalid', 'Reportable under 6041/6041A and Authority for Exception': 'no'},
}
